<?php
/*
=================================================================================================================
wow_option - Retrieve an option / or false if not set
=================================================================================================================
*/
if ( !function_exists ( 'wow_option' ) ){
	function wow_option( $value , $from_array_value = NULL ){
		$options = get_option( 'fribba_options' );
		if ( !empty ( $options ) ){
			if ( isset ( $options[ $value ] ) ) {
					if ( $from_array_value ){
						return $options[ $value ][ $from_array_value ];
					}
				return $options[ $value ];
			}
		}
		return false;
	}
}
/*
=================================================================================================================
wow_send_jQuery_in_footer() - send jquery to footer if switched on from theme options
=================================================================================================================
*/

if ( wow_option( 'js-footer' ) == '1' ){
	function wow_send_jQuery_in_footer () {
		global $wp_scripts;
		$wp_scripts->registered['jquery']->extra['group'] = 1;
		$wp_scripts->registered['jquery-core']->extra['group'] = 1;
		$wp_scripts->registered['jquery-migrate']->extra['group'] = 1;
	}
	add_action ( 'wp_head', 'wow_send_jQuery_in_footer', 1, 0 );
}

/*
=================================================================================================================
wow_critical_css() - inline critical css in head
=================================================================================================================
*/
function wow_critical_css () { ?>
	<style id="critical-css"><?php get_template_part( 'templates/critical-css' ); ?></style>
<?php }

function wow_dequeue_css () {
	wp_dequeue_style( 'style' );
}
if ( wow_option( 'inline-css' ) == '1' ){
	add_action( 'wp_enqueue_scripts' , 'wow_dequeue_css', 2 );	
	add_action( 'wp_head' , 'wow_critical_css' );
}

/*
=================================================================================================================
wow_deregister_gutenberg_styles() - Disable Gutenberg styles
=================================================================================================================
*/

if ( wow_option( 'gutenberg' ) == 'remove' ){
	add_action( 'wp_print_styles', 'wow_deregister_gutenberg_styles', 1 );
	function wow_deregister_gutenberg_styles() {
		wp_dequeue_style( 'wp-block-library' );
	}
}

/*
=================================================================================================================
wow_move_gutenberg_styles_footer() - Move Gutenberg styles in footer
=================================================================================================================
*/

if ( wow_option( 'gutenberg' ) == 'move' ){
	add_action( 'wp_print_styles', 'wow_deregister_gutenberg_head', 100 );
	function wow_deregister_gutenberg_head() {
		wp_dequeue_style( 'wp-block-library' );
	}
	function wow_move_gutenberg_styles_footer() {
		wp_enqueue_style( 'wp-block-library' , includes_url().'css/dist/block-library/style.min.css', array(), '1.0', 'all' );		
	}
	add_action( 'get_footer', 'wow_move_gutenberg_styles_footer' );
}

/*
=================================================================================================================
wow_disable_emojis() - disable wordpress emoji.js
=================================================================================================================
*/
if ( wow_option( 'disable-emoji' ) == '1' ){
	function wow_disable_emojis() {
		remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
		remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
		remove_action( 'wp_print_styles', 'print_emoji_styles' );
		remove_action( 'admin_print_styles', 'print_emoji_styles' );	
		remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
		remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );	
		remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
		add_filter( 'tiny_mce_plugins', 'wow_disable_emojis_tinymce' );
	}
	add_action( 'init', 'wow_disable_emojis' );

	/**
	 * Filter function used to remove the tinymce emoji plugin.
	 * 
	 * @param    array  $plugins  
	 * @return   array             Difference betwen the two arrays
	 */
	function wow_disable_emojis_tinymce( $plugins ) {
		if ( is_array( $plugins ) ) {
			return array_diff( $plugins, array( 'wpemoji' ) );
		} else {
			return array();
		}
	}
}


if ( wow_option( 'leverage-broswer-caching' ) == '1' ){
	function wow_add_leverage_broswer_caching() {
		//get htaccess file path
		$htaccess_file = wp_normalize_path( ABSPATH . '.htaccess' );

		if ( file_exists( $htaccess_file ) ) {
			
			$current_htaccess = file_get_contents( $htaccess_file );

			//unique string
			$unique = 'FRIBBABROWSERCACHE';
			
			$exists = false;

			//code is already added
			if ( strpos( $current_htaccess, $unique ) !== false ) {
				$exists = true;
			}
			
			//code is inexistent so we add it
			if ( ! $exists ) {

				$expires  = "\n";
				$expires .= '# FRIBBABROWSERCACHESTART Browser Caching' . "\n";
				$expires .= '<IfModule mod_expires.c>' . "\n";
				$expires .= 'ExpiresActive On' . "\n";
				$expires .= 'ExpiresByType image/gif "access 1 year"' . "\n";
				$expires .= 'ExpiresByType image/jpg "access 1 year"' . "\n";
				$expires .= 'ExpiresByType image/jpeg "access 1 year"' . "\n";
				$expires .= 'ExpiresByType image/png "access 1 year"' . "\n";
				$expires .= 'ExpiresByType image/x-icon "access 1 year"' . "\n";
				$expires .= 'ExpiresByType text/css "access 1 month"' . "\n";
				$expires .= 'ExpiresByType text/javascript "access 1 month"' . "\n";
				$expires .= 'ExpiresByType text/html "access 1 month"' . "\n";
				$expires .= 'ExpiresByType application/javascript "access 1 month"' . "\n";
				$expires .= 'ExpiresByType application/x-javascript "access 1 month"' . "\n";
				$expires .= 'ExpiresByType application/xhtml-xml "access 1 month"' . "\n";
				$expires .= 'ExpiresByType application/pdf "access 1 month"' . "\n";
				$expires .= 'ExpiresByType application/x-shockwave-flash "access 1 month"' . "\n";
				$expires .= 'ExpiresDefault "access 1 month"' . "\n";
				$expires .= '</IfModule>' . "\n";
				$expires .= '# END Caching FRIBBABROWSERCACHEEND' . "\n";

				if ( is_readable( $htaccess_file ) && is_writable( $htaccess_file ) ) {
					$final_htaccess = '';
					$final_htaccess .= $current_htaccess.$expires;
					file_put_contents( $htaccess_file, $final_htaccess );
				}
			
			}
		
		} //enf if htaccess_file exists
	}
	wow_add_leverage_broswer_caching();
}
else{
	function wow_remove_leverage_broswer_caching() {
		//get htaccess file path
		$htaccess_file = wp_normalize_path( ABSPATH . '.htaccess' );

		if ( file_exists( $htaccess_file ) ) {
			
			$current_htaccess = file_get_contents( $htaccess_file );

			//unique string
			$unique = 'FRIBBABROWSERCACHE';
			
			$exists = false;

			//code is already added
			if ( strpos( $current_htaccess, $unique ) !== false ) {
				$exists = true;
			}
			
			//code is existent remove it
			if ( $exists ) {

				$pattern 			= '/#\s?FRIBBABROWSERCACHESTART.*?FRIBBABROWSERCACHEEND/s';
				$current_htaccess 	= preg_replace( $pattern, '', $current_htaccess );
				$current_htaccess 	= preg_replace( "/\n+/","\n", $current_htaccess );

				file_put_contents( $htaccess_file, $current_htaccess );				
			
			}
		
		} //enf if htaccess_file exists
	}
	wow_remove_leverage_broswer_caching();
}	




if ( wow_option( 'enable-gzip' ) == '1' ){
	function wow_enable_gzip() {
		//get htaccess file path
		$htaccess_file = wp_normalize_path( ABSPATH . '.htaccess' );

		if ( file_exists( $htaccess_file ) ) {
			
			$current_htaccess = file_get_contents( $htaccess_file );

			//unique string
			$unique = 'FRIBBAGZIPSTART';
			
			$exists = false;

			//code is already added
			if ( strpos( $current_htaccess, $unique ) !== false ) {
				$exists = true;
			}
			
			//code is inexistent so we add it
			if ( ! $exists ) {

				$gzip  = "\n";
				$gzip .= '# FRIBBAGZIPSTART' . "\n";
				$gzip .= '<IfModule mod_deflate.c>' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/javascript' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/rss+xml' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/vnd.ms-fontobject' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/x-font' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/x-font-opentype' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/x-font-otf' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/x-font-truetype' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/x-font-ttf' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/x-javascript' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/xhtml+xml' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE application/xml' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE font/opentype' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE font/otf' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE font/ttf' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE image/svg+xml' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE image/x-icon' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE text/css' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE text/html' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE text/javascript' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE text/plain' . "\n";
				$gzip .= 'AddOutputFilterByType DEFLATE text/xml' . "\n";
				$gzip .= '</IfModule>' . "\n";
				$gzip .= '# FRIBBAGZIPEND' . "\n";

				if ( is_readable( $htaccess_file ) && is_writable( $htaccess_file ) ) {
					$final_htaccess = '';
					$final_htaccess .= $current_htaccess.$gzip;
					file_put_contents( $htaccess_file, $final_htaccess );
				}
			
			}
		
		} //enf if htaccess_file exists
	}
	wow_enable_gzip();
}
else{
	function wow_disable_gzip() {
		//get htaccess file path
		$htaccess_file = wp_normalize_path( ABSPATH . '.htaccess' );

		if ( file_exists( $htaccess_file ) ) {
			
			$current_htaccess = file_get_contents( $htaccess_file );

			//unique string
			$unique = 'FRIBBAGZIPSTART';
			
			$exists = false;

			//code is already added
			if ( strpos( $current_htaccess, $unique ) !== false ) {
				$exists = true;
			}
			
			//code is existent remove it
			if ( $exists ) {

				$pattern 			= '/#\s?FRIBBAGZIPSTART.*?FRIBBAGZIPEND/s';
				$current_htaccess 	= preg_replace( $pattern, '', $current_htaccess );
				$current_htaccess 	= preg_replace( "/\n+/","\n", $current_htaccess );

				file_put_contents( $htaccess_file, $current_htaccess );				
			
			}
		
		} //enf if htaccess_file exists
	}
	wow_disable_gzip();
}	


function wow_style_loader_tag( $tag ){
	$tag = preg_replace( "/rel='stylesheet' id='wow-google-fonts-css'/", "rel='preload' id='wow-google-fonts-css' as='style'", $tag );
	return $tag;
}

function wow_disable_csf_google_font(){
	wp_deregister_style( 'csf-google-web-fonts-fribba_options' );
}
add_action( 'wp_print_styles','wow_disable_csf_google_font' );


//add_filter('style_loader_tag','wow_style_loader_tag');