<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
Recent Posts Widget
=================================================================================================================
*/
add_action( 'widgets_init', 'wow_recent_posts_widget' );
function wow_recent_posts_widget() {
	register_widget('wow_recent_posts_widget');
}

class wow_recent_posts_widget extends WP_Widget {
	function __construct() {
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'wow_recent_posts_widget', 'description' => esc_attr__('Display Recent Posts in a nice style','fribba') );
		 
		/* Widget control settings. */
		$control_ops = array( 'id_base' => 'wow_recent_posts_widget' );
		 
		/* Create the widget. */
		parent::__construct( 'wow_recent_posts_widget', esc_attr__('Fribba Recent Posts','fribba'), $widget_ops, $control_ops );
	}
	 
	function widget( $args, $instance ) {
		
		$post_no =  !empty($instance['post_no']) ?  strip_tags(absint($instance['post_no']))  : '' ;
		$title   = !empty($instance['title']) ?  strip_tags(esc_attr($instance['title']))  : '' ;
		
		$query_args = array( 'posts_per_page' => $post_no ); 
		$query = new WP_Query( $query_args );
		
		while ( $query->have_posts() ){
				$query->the_post();
				$is_gallery = get_post_format() == 'gallery' ? true : false;
				if ( $is_gallery ){
					wp_enqueue_script( 'slick', WOW_URI."/js/slick.min.js", '', '', true );
					continue;
				}
		}
		wp_reset_postdata();
		extract( $args );

	?>
	<div class="widget"><!-- widget -->
		<h2><?php echo esc_attr( $title ); ?></h2><span class="line"></span>
			<div class="sidebar-posts">
				
				<?php while ( $query->have_posts() ) { $query->the_post(); ?>			
				
					<article <?php post_class(); ?>>
						<div class="post-widget">
							<div class="wow-row">
								<div class="col-desktop-4 col-tablet-4 col-small-tablet-12 col-mobile-12 thumb">
								<?php wow_post_thumb( false,  false , true , false , true ); ?>
								</div>
								<div class="col-desktop-8 col-tablet-8 col-small-tablet-12 col-mobile-12">
									<h4 class="post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
									<?php wow_views_ouput( 'Views' ); ?>
								</div>
							</div>
						</div>
					</article>					
				
				<?php } wp_reset_postdata(); ?>
			</div>
	</div><!--/ widget -->
<?php	
}
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		 
		/* Strip tags (if needed) and update the widget settings. */
		$instance['title']   		 =   strip_tags(esc_attr($new_instance['title']));
		$instance['post_no'] 		 =   strip_tags(absint($new_instance['post_no']));
		return $instance;
	}

	function form( $instance ) {
		
		/* Set up some default widget settings. */
		$title	  			= isset($instance['title']) ? strip_tags(esc_attr($instance['title'])) : esc_attr__('Latest news','fribba');
		$post_no  			= isset($instance['post_no']) ? strip_tags(absint( $instance['post_no'])) : 2;
	

		?>
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title','fribba'); ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($title); ?>">
		</p>
		
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'post_no' )); ?>"><?php esc_html_e('Number of posts','fribba'); ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'post_no' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'post_no' )); ?>" value="<?php echo esc_attr($post_no); ?>">
		</p>
		
	<?php
	}
}