<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/*
=================================================================================================================
wow_register_required_plugins() - used to auto-install plugins on theme activation
=================================================================================================================
*/
function wow_register_required_plugins() {
    /**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(
		array(
            'name'               => 'Fribba Core', // The plugin name.
            'slug'               => 'fribba-core', // The plugin slug (typically the folder name).
            'source'             =>  WOW_DIR.'/inc/plugins/fribba-core.zip' , // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
            'version'            => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url'       => '', // If set, overrides default API URL and points to an external URL.
        ),		
		array(
            'name'               => 'Codestar Framework', // The plugin name.
            'slug'               => 'codestar-framework', // The plugin slug (typically the folder name).
            'source'             =>  WOW_DIR.'/inc/plugins/codestar-framework.zip' , // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
            'version'            => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url'       => '', // If set, overrides default API URL and points to an external URL.
        ),

    );

    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'id'           => 'fribba',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => esc_html__( 'Install Required Plugins', 'fribba' ),
            'menu_title'                      => esc_html__( 'Install Plugins', 'fribba' ),
            'installing'                      => esc_html__( 'Installing Plugin: %s', 'fribba' ), // %s = plugin name.
            'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'fribba' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'Before moving on, please install the following plugins: %1$s.', 'fribba' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'fribba' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'fribba' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'fribba' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'fribba' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'fribba' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'fribba' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'fribba' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'fribba' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'fribba' ),
            'return'                          => esc_html__( 'Return to Required Plugins Installer', 'fribba' ),
            'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'fribba' ),
            'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s', 'fribba' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );

    tgmpa( $plugins, $config );

}
add_action( 'tgmpa_register', 'wow_register_required_plugins' );


/*
=================================================================================================================
wow_plugin_updater() - plugin updater
=================================================================================================================
*/
add_action( 'admin_init', 'wow_plugin_updater' );
function wow_plugin_updater() {
	
	if ( ! class_exists( 'TGM_Updater' ) ) {
		require WOW_DIR . '/inc/tgm/class-tgm-updater.php';
	}
	
	//Fribba Core
	if( function_exists( 'wow_fribba_plugins_core' ) ) {
		$plugin_data = get_plugin_data( trailingslashit( WP_PLUGIN_DIR ).'fribba-core/fribba.php');
		$args = array(
			'plugin_name' => esc_html__('Fribba Core', 'fribba'),
			'plugin_slug' => 'fribba-core',
			'plugin_path' => 'fribba-core/fribba.php',
			'plugin_url'  => trailingslashit( WP_PLUGIN_URL ) . 'fribba-core',
			'remote_url'  => esc_url( 'https://wowlayers.com/auth/required_plugins/fribba/fribba-core.json' ),
			'version'     => $plugin_data['Version'],
			'key'         => ''
		);
		$tgm_updater = new TGM_Updater( $args );
	}
	
	//Codestar Framework
	if( class_exists( 'CSF' ) ) {
		$plugin_data = get_plugin_data( trailingslashit( WP_PLUGIN_DIR ).'codestar-framework/codestar-framework.php');
		$args = array(
			'plugin_name' => esc_html__('Codestar Framework', 'fribba'),
			'plugin_slug' => 'codestar-framework',
			'plugin_path' => 'codestar-framework/codestar-framework.php',
			'plugin_url'  => trailingslashit( WP_PLUGIN_URL ) . 'codestar-framework',
			'remote_url'  => esc_url( 'https://wowlayers.com/auth/required_plugins/fribba/codestar-framework.json' ),
			'version'     => $plugin_data['Version'],
			'key'         => ''
		);
		$tgm_updater = new TGM_Updater( $args );
	}
}

/*
=================================================================================================================
wow_get_envato_purchase_code() - get the envato purchase code from db or from envato if hosted there
=================================================================================================================
*/
function wow_get_envato_purchase_code() {
	
	$purchase_code = 'MGN3eXo5-aWst-M2k3-dS00-ZHA0LTNkamgt';
	return $purchase_code;
	
}

/*
=================================================================================================================
wow_upgrader_pre_download() - Get the secure download URL of a package ( theme / plugin )
=================================================================================================================
*/
function wow_upgrader_pre_download( $reply, $package, $upgrader ) {
	
	if( strpos( $package, 'wowlayers.live' ) !== false && strpos( $package, 'envato-wordpress-toolkit' ) === false ) {
		
		//check if there is any purchase code registered
		if( !wow_get_envato_purchase_code() ) {
			if ( !$upgrader->bulk ){
				return new WP_Error('fribba-code-empty', sprintf( wp_kses_post( __( '<div class="notice notice-error is-dismissible"><p>Purchase code verification failed. <a href="%s" target="_blank">Activate Fribba</a> in order to be able to download / update.</p></div>', 'fribba' ) ),esc_url( admin_url( 'options-general.php?page=fribba-dashboard.php' ) ) ) );
			}
			else{
				return new WP_Error('fribba-code-empty', sprintf( wp_kses_post( __( 'Purchase code verification failed. <a href="%s">Activate Fribba</a> in order to be able to download / update', 'fribba' ) ),esc_url( admin_url( 'options-general.php?page=fribba-dashboard.php' ) ) ) );
			}
		}

		//checks
		$query = add_query_arg( array(
			'code' => wow_get_envato_purchase_code(),
			'site_url' => get_site_url(),
			'package' => $package,
		), 'https://wowlayers.com/auth/key.php' );			

		//get response
		$response = wp_remote_get( $query, array( 'timeout' => 20 ) );
		
		//if response error
		if ( is_wp_error( $response ) ) {
			return new WP_Error('fribba_communication_error', sprintf( __( 'Could not communicate with Fribba server. Please try again or contact us if the problem persists.','fribba' ) ) );
		}
		
		//license checks
		if( $response['body'] ){
			if ( !$upgrader->bulk ){
				return new WP_Error( 'license_checks' , sprintf( wp_kses_post( '<div class="notice notice-error is-dismissible"><p>'. esc_attr( $response['body'] ).'</p></div>' ) ) );
			}
			else{
				return new WP_Error( 'license_checks' , esc_attr( $response['body'] ) );			
			}
		}

		//sucess - package download url
		$download_url = download_url( 'https://wowlayers.com/auth/download.php?code='.esc_attr( wow_get_envato_purchase_code() ).'&package='.esc_attr( $package ).'&site_url='.esc_url( get_site_url() ) );
		
		//var_dump('https://wowlayers.com/auth/download.php?code='.esc_attr( wow_get_envato_purchase_code() ).'&package='.esc_attr( $package ).'&site_url='.esc_url( get_site_url() ));

		//if package error
		if ( is_wp_error( $download_url ) ) {
			return new WP_Error('fribba_communication_error', sprintf( __( 'Could not communicate with Fribba server. Please try again or contact us if the problem persists.','fribba' ) ) );
		}

		return $download_url;
		
	}

	return $reply;

}
add_filter( 'upgrader_pre_download', 'wow_upgrader_pre_download', 10, 3 );


/*
=================================================================================================================
wow_pre_set_site_transient_update_themes() - check for theme updates
=================================================================================================================
*/
function wow_pre_set_site_transient_update_themes( $transient ) {

	$response = wp_remote_get( 'https://wowlayers.com/auth/themes/fribba/fribba.json', array( 'timeout' => 5 ) );
	
	if ( is_wp_error( $response ) ) {
		return $transient;
	}

	$body = wp_remote_retrieve_body( $response );
	
	$data = json_decode( $body, 1 );
	if ( ! isset( $data['new_version'] ) ) {
		return $transient;
	}

	$new_version = $data['new_version'];

	// Save update info there is a new version
	$theme = wp_get_theme('fribba');
	if ( version_compare( $theme->get( 'Version' ), $new_version, '<' ) ) {
		$transient->response[ 'fribba' ] = array(
			'slug' => 'fribba',
			'theme' => 'fribba',
			'new_version' => $new_version,
			'url' => $data['url'],
			'package' => $data['package'],
			'changelog' => $data['changelog'],
		);
	}

	return $transient;
}
add_filter( 'pre_set_site_transient_update_themes', 'wow_pre_set_site_transient_update_themes', 10, 3 );


/*
=================================================================================================================
wow_theme_update_notice() - Display a notice that new version is available
=================================================================================================================
*/
function wow_theme_update_notice() {
	
	if ( !current_user_can('update_themes' ) ){
		return false;
	}
	
	if ( !isset( $themes_update ) ){
		$themes_update = get_site_transient( 'update_themes' );
	}
	
	if ( isset( $themes_update->response['fribba'] ) ) {
		
		$update = $themes_update->response['fribba'];
		$theme = wp_prepare_themes_for_js( array( wp_get_theme('fribba') ) );
		$update_url = wp_nonce_url( admin_url( 'update.php?action=upgrade-theme&amp;theme=' . urlencode( 'fribba' ) ), 'upgrade-theme_fribba' );
		
		if ( isset( $theme[0] ) && $theme[0]['hasUpdate'] ) {
			
			echo '<div class="fribba-update-notice notice notice-warning is-dismissible">';
			echo '<p>'.sprintf( wp_kses( __( 'There is a new version of Fribba theme available. Your current version is <strong>%s</strong>. Update to <strong>%s</strong>.', 'fribba'), array('strong' => array())), $theme[0]['version'], $update['new_version']).'</p>';
			
			echo '<p><strong><a href="#" class="fribba-view-details-link">View update details</a></strong>'.sprintf( wp_kses( __( ' or <strong><a href="%s" class="fribba-update-link">Update now</a></strong>.', 'fribba'), array('strong' => array(), 'a' => array('href' => array(), 'class' => array()))),  $update_url).'</p>';
			echo '</div>';
			
		}
	}
}
add_action( 'admin_notices', 'wow_theme_update_notice' );

/*
=================================================================================================================
wow_theme_plugins_update_notice() - Display a notice that new version of plugin(s) is / are available
=================================================================================================================
*/
function wow_theme_plugins_update_notice() {
	if ( !current_user_can('update_plugins' ) )
		return false;
	$plugins = get_site_transient('update_plugins');
	$wow_plugins = array(
		'fribba-core/fribba.php',
		'codestar-framework/codestar-framework.php',
	);
	if ( isset( $plugins->response ) && is_array( $plugins->response ) ) {
		
		$plugins_ids = array_keys( $plugins->response );
		
		foreach ( $plugins_ids as $plugin_file ) {
			
			if( in_array( $plugin_file, $wow_plugins ) ) {
				
				$plugin_data = get_plugin_data( trailingslashit(WP_PLUGIN_DIR).$plugin_file );
				$plugin_update = $plugins->response[$plugin_file];
				
				echo '<div class="fribba-update-notice notice notice-warning is-dismissible">';
				echo '<p>'.sprintf( wp_kses( __( 'There is a new version of <strong>%s</strong> plugin available. Your current version is <strong>%s</strong>. Update to <strong>%s</strong>.', 'fribba'), array( 'strong' => array() ) ), $plugin_data['Name'], $plugin_data['Version'], $plugin_update->new_version ).'</p>';
				echo '<p>'.sprintf( wp_kses( __( '<strong><a href="%s">Update now</a></strong>.', 'fribba' ), array( 'strong' => array(), 'a' => array( 'href' => array() ) ) ), esc_url( admin_url('update-core.php') ) ).'</p>';
				echo '</div>';
				
			}
		}
	}
}
add_action( 'admin_notices', 'wow_theme_plugins_update_notice' );

/*
=================================================================================================================
wow_theme_update_confirmation() - Display a confirmation box on theme update
=================================================================================================================
*/
add_action('wp_ajax_wow_theme_update_confirmation', 'wow_theme_update_confirmation');
function wow_theme_update_confirmation() {
?>
<div class="fribba-update">
	<div class="fribba-update-inner">
		<div class="confirm-update-holder">
			<h1><i class="wow-webapplication-exclamation-square"></i><?php esc_html_e('Very important notice!', 'fribba'); ?></h1>
			<p>
			<?php 
				printf( '%s<strong>%s</strong>%s<strong>%s</strong>', 
					esc_html__( 'Before you update the theme', 'fribba' ), 
					esc_html__( ' we strongly recommend ', 'fribba' ),
					esc_html__( 'that you make a ', 'fribba' ),
					esc_html__( 'full website and database backup.', 'fribba' )
				); ?>
			</p>			
			<p>
			<?php 
				printf( '%s<strong>%s</strong>%s<strong>%s</strong>%s<strong>%s</strong>', 
					esc_html__( 'If you have ', 'fribba' ), 
					esc_html__( 'modified ', 'fribba' ),
					esc_html__( 'any of the ', 'fribba' ), 
					esc_html__( 'main theme files, ', 'fribba' ),
					esc_html__( 'please note that they will be ', 'fribba' ),
					esc_html__( 'overridden.', 'fribba' )
				); ?>
			</p>
			<p class="lighter">
			<?php 
				printf( '%s<br>%s<br>%s<a href="%s" target="_blank">%s</a>', 
					esc_html__( 'Best practice if you want to modify theme files, is to use Fribba child theme instead.', 'fribba' ), 
					esc_html__( ' Child theme is included in the main ZIP package that you downloaded from themeforest.', 'fribba' ),
					esc_html__( ' More info about child themes can be found ', 'fribba' ),
					esc_url( 'https://developer.wordpress.org/themes/advanced-topics/child-themes/'),
					esc_html__( 'here', 'fribba' )
				); ?>			
			</p>		
			<div class="confirm-checkbox">
				<label for="fribba-confirm-checkbox"><input type="checkbox" name="confirm" id="fribba-confirm-checkbox" value="1" />
					<?php esc_html_e('I have read the notice above and I confirm I want to proceed with the update.', 'fribba'); ?>
				</label>
			</div>
			<div class="confirm-button">
				<button id="fribba-confirm-button" disabled="disabled"><?php esc_html_e('Proceed with update', 'fribba'); ?></button>
			</div>
		</div>
	</div>
</div>
<?php
	die(-1);
}

/*
=================================================================================================================
wow_change_log() - Get theme changelog page
=================================================================================================================
*/
add_action('wp_ajax_wow_change_log', 'wow_change_log');
function wow_change_log() {
	
	$response = wp_remote_get( 'https://wowlayers.com/auth/themes/fribba/changelog.html' );
	
	if ( is_array( $response ) ) {
		?>
		<div class="fribba-update changelogs">
		<?php
			$body = $response['body'];	  
			echo wp_kses_post( $body );
		?>
		<div>
		<?php
		die(-1);
	}	
	

}