<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
wow_column_views_heading - Add column heading Views in dashboard posts
=================================================================================================================
*/
function wow_column_views_heading( $columns ) {
    if ( get_post_type() == 'post' ){
		$columns['post_views'] = esc_attr__( 'Views','fribba' );
		return $columns;
	}
}
/*
=================================================================================================================
wow_column_views - Add column post views in dashboard posts
=================================================================================================================
*/
function wow_column_views( $column ) {
    if ( get_post_type() == 'post' ){
		if ( $column === 'post_views') {
			echo esc_attr( wow_get_post_views() ).' '.esc_attr__( 'Views','fribba' );
		}
	}
}
add_filter( 'manage_posts_columns', 'wow_column_views_heading' );
add_action( 'manage_posts_custom_column', 'wow_column_views' );



/*
=================================================================================================================
wow_column_image_heading - Add column heading Image in dashboard posts
=================================================================================================================
*/
function wow_column_image_heading( $columns ) {
    if ( get_post_type() == 'post' ){
		$columns['image'] = esc_attr__( 'Image','fribba' );
		return $columns;
	}
}
/*
=================================================================================================================
wow_column_image - Add column image display in dashboard posts
=================================================================================================================
*/
function wow_column_image( $column ) {
    if ( get_post_type() == 'post' ){
		
		if ( $column === 'image') {
		   if ( get_post_format() == false ){
			   if ( has_post_thumbnail() ){
					 $post_thumb = get_the_post_thumbnail_url( get_the_ID() , 'admin-thumb' ) ;
					 echo '<img src=" '. esc_url( $post_thumb ) .' " class="admin-thumb">';
				   }
		   }
			elseif ( get_post_format() == 'video' ){
				echo esc_attr__('Video','fribba');
			}		
			elseif ( get_post_format() == 'audio' ){
				echo esc_attr__('Audio','fribba');
			}
			else{
				echo esc_attr__('Gallery','fribba');
			}
		}
	}
}
add_filter( 'manage_posts_columns', 'wow_column_image_heading',1 );
add_action( 'manage_posts_custom_column', 'wow_column_image',1 );


/*
=================================================================================================================
wow_column_downloads_heading - Add column heading Downlaods in dashboard posts
=================================================================================================================
*/
function wow_column_downloads_heading( $columns ) {
    if ( get_post_type() == 'post' ){
		$columns['post_downloads'] = esc_attr__( 'Downloads','fribba' );
		return $columns;
	}
}
/*
=================================================================================================================
wow_column_downloads - Add column post downloads count in dashboard posts
=================================================================================================================
*/
function wow_column_downloads( $column ) {
    if ( get_post_type() == 'post' ){
		if ( $column === 'post_downloads') {
			$count_downloads = wow_get_download_views();
			if ( $count_downloads > 0 ){
				echo esc_attr( $count_downloads ).' '.esc_attr__( 'Downloads','fribba' );
			}
			else{
				echo esc_attr__('N/A','fribba');
			}
		}
	}
}
add_filter( 'manage_posts_columns', 'wow_column_downloads_heading' );
add_action( 'manage_posts_custom_column', 'wow_column_downloads' );




/*
=================================================================================================================
wow_on_theme_activation() - Redirect user to welcome page on theme switch
=================================================================================================================
*/
function wow_on_theme_activation(){
    wp_safe_redirect( esc_url ( admin_url('options-general.php?page=fribba-dashboard.php' ) ) );
}
add_action("after_switch_theme", "wow_on_theme_activation");


/*
=================================================================================================================
wow_fribba_menu() - Add fribba menu to options page
=================================================================================================================
*/
function wow_fribba_menu() {
	add_options_page( 
		'Activate Fribba',
		'Fribba',
		'manage_options',
		'fribba-dashboard.php',
		'wow_dashboard_page'
	);
}
add_action( 'admin_menu', 'wow_fribba_menu' );



/*
=================================================================================================================
wow_dashboard_page() - Print the dashboard page
=================================================================================================================
*/
function wow_dashboard_page(){
	?>
	<div class="fribba-wrap"><!-- fribba-wrap -->

			<div class="top-info">
				<h1><?php esc_html_e('Hello, fribber!','fribba'); ?></h1>
				<p>
					<?php
						echo sprintf( '%s<br>%s', 
							esc_html__( 'Thanks for choosing Fribba.', 'fribba' ), 
							esc_html__( 'Activate the theme or read the tutorials.', 'fribba' )
						);
					?>
				</p>
			</div>		

		<div class="wow-row flex"><!-- wow-row -->
		
			<div class="wow-box flex wow-register-theme <?php if( get_option( "fribba_license_active" ) == "inactive" || get_option( "fribba_license_active" ) != "active" ) { echo 'show'; } ?>">
				<div class="wow-box-inner key">
					<div class="info-holder box">
						<h1><?php esc_html_e('Activate theme','fribba'); ?><i class="wow-webapplication-lock"></i></h1>
						<p><?php esc_html_e('Register your theme to receive automatic updates.','fribba'); ?><br/>
							<a href="https://help.market.envato.com/hc/en-us/articles/202822600-Where-Is-My-Purchase-Code-" target="_blank"><?php esc_html_e('Where can I find the code?','fribba'); ?></a>
						</p>
						<div class="holder">
							<input type="text" name="activate-fribba" placeholder="<?php esc_attr_e('Add your purchase code here','fribba'); ?>">
							<a href="#" target="_blank" class="go_to_activate-fribba buttons activate in-box orange"><?php esc_html_e('Register Fribba','fribba'); ?></a>
						</div>
					</div>
				</div>			
			</div>			

			<div class="wow-box flex wow-theme-activated <?php if( get_option( "fribba_license_active" ) == "active"  ) { echo 'show'; } ?>">
				<div class="wow-box-inner activated">
					<div class="info-holder box">
						<h1><?php esc_html_e('Yay! Your theme is activated','fribba'); ?><i class="wow-webapplication-unlocked green"></i></h1>
						<p><?php esc_html_e('Congrats. Your theme is registered.','fribba'); ?><br>
						<?php esc_html_e('Remember to de-register first, if you want to use it on another domain.','fribba'); ?></p>
						<div class="holder">
							<input type="text" name="de-activate-fribba" value="<?php echo esc_attr( get_option("envato_purchase_code_16116762") ); ?>">
							<a href="#" target="_blank" class="buttons activate in-box green de-activate-fribba"><?php esc_html_e('De-Register Fribba','fribba'); ?></a>
						</div>
					</div>
				</div>			
			</div>
			
			<div class="wow-box flex">
				<div class="wow-box-inner newbie">
					<div class="info-holder box">
						<h1><?php esc_html_e('Useful info','fribba'); ?><i class="wow-webapplication-learn"></i></h1>
						<p>
							<?php esc_html_e('You can comb through the documentation.','fribba'); ?>
							<?php esc_html_e('By doing this, you will have basic knowledge on how to use the theme, in no time!','fribba'); ?>
						</p>
						<div class="holder">
							<a href="https://wowlayers.com/docs/fribba/index.html" target="_blank" class="buttons in-box green"><?php esc_html_e('Read documentation','fribba'); ?></a>
							<a href="<?php echo esc_url ( admin_url('admin.php?page=fribba-options' ) ) ?>" class="buttons in-box blue"><?php esc_html_e('Theme Options','fribba'); ?></a>
							<a href="https://wowlayers.com/auth/themes/fribba/changelog.html" target="_blank" class="buttons in-box grey"><?php esc_html_e('Changelog','fribba'); ?></a>
						</div>
					</div>
				</div>			
			</div>			
	
		</div><!-- /wow-row -->		

	</div><!--/ fribba-wrap -->
	<?php 
	//require_once( WOW_DIR.'/changelog.html' );
}


/*
=================================================================================================================
wow_admin_scripts() - we activate the theme here
=================================================================================================================
*/
function wow_admin_scripts() {
	$screen = get_current_screen();
	if( $screen->base == 'settings_page_fribba-dashboard' ){
		
		wp_register_script( 'wow-theme-register', WOW_URI."/js/register.js", array('jquery'), NULL, true );
		wp_localize_script( 'wow-theme-register', 'wow_purchase_code', array( 'ajaxurl' => esc_url( site_url() ) . '/wp-admin/admin-ajax.php' ) );	
		wp_enqueue_script( 'wow-theme-register' );

		wp_register_script( 'wow-theme-deregister', WOW_URI."/js/deregister.js", array('jquery'), NULL, true );
		wp_localize_script( 'wow-theme-deregister', 'wow_purchase_code', array( 'ajaxurl' => esc_url( site_url() ) . '/wp-admin/admin-ajax.php' ) );	
		wp_enqueue_script( 'wow-theme-deregister' );					
		
	}	
}
add_action( 'admin_enqueue_scripts', 'wow_admin_scripts' );


/*
=================================================================================================================
Function wow_purchase_code_activation_handler() - Purchase code activation
=================================================================================================================
*/
function wow_purchase_code_activation_handler(){

	if( $_POST['action'] == 'wow_purchase_code' ){
		
		if( $_POST['purchase_code'] ){
			
			$purchase_code = stripslashes( wp_filter_kses( $_POST['purchase_code'] ));
			$purchase_code = trim( $purchase_code );
			
			$query = add_query_arg( array(
				'code' => esc_attr( $purchase_code ),
				'site_url' => get_site_url(),
			), 'https://wowlayers.com/auth/register.php' );

			$response = wp_remote_get( $query, array( 'timeout' => 20 ) );				

			if ( is_wp_error( $response ) ) {
				die( esc_html__("Could not connect to server","fribba") );
			} 
			elseif( $response["body"] == "success" ){
				update_option("fribba_license_active", "active" );
				die("success");
			}
			else {
				die( $response["body"] );
			}			
			
		}
	}		
} 
add_action('wp_ajax_wow_purchase_code', 'wow_purchase_code_activation_handler'); // wp_ajax_{action}


/*
=================================================================================================================
Function wow_purchase_code_deactivation_handler() - Purchase code deactivation
=================================================================================================================
*/
function wow_purchase_code_deactivation_handler(){
	
	
	if( $_POST['action'] == 'wow_purchase_code' && $_POST['do_action'] == 'deregister' ){
		
			
		if( get_option("fribba_license_active") == "active" ){
				
			$query = add_query_arg( array(
				'code' => wow_get_envato_purchase_code(),
				'site_url' => get_site_url(),
			), 'https://wowlayers.com/auth/deregister.php' );

			$response = wp_remote_get( $query, array( 'timeout' => 20 ) );			
			
			if ( is_wp_error( $response ) ) {
				die( esc_html__("Could not connect to server","fribba") );
			} 
			elseif( $response["body"] == "success" ){
				update_option("fribba_license_active", "active" );
				die("success");
			}
			elseif( $response["body"] == "license-not-found" ) {

					die( esc_html__("License not found","fribba") );
			}	
			else{
				die( $response["body"] );
			}
		}
	}		
} 
add_action( 'wp_ajax_wow_purchase_code', 'wow_purchase_code_deactivation_handler' ); // wp_ajax_{action}

/*
=================================================================================================================
wow_welcome_admin_body_class() - add body class to admin
=================================================================================================================
*/
add_filter( 'admin_body_class', 'wow_welcome_admin_body_class' );

function wow_welcome_admin_body_class( $classes ) {
	
	$screen = get_current_screen();
	if( $screen->base == 'settings_page_fribba-dashboard' ){
		$classes .= 'fribba-pages';
	}
	
	return $classes;
}


function wow_set_theme_active_code(){
	update_option("fribba_license_active", "active" );
}
add_action( 'after_switch_theme', 'wow_set_theme_active_code' );

/*
function move_columns_head( $defaults ) {  

	if ( get_post_type() == 'post' ){
		$new = array();
		$image = $defaults['image'];  // save the tags column
		unset($defaults['image']);   // remove it from the columns list

		foreach( $defaults as $key => $value ) {
			if( $key=='title' ) {  // when we find the title column
			   $new['image'] = $image;  // put the tags column before it
			}    
			$new[$key] = $value;
		}  

		return $new;  
	}
} 
add_filter('manage_posts_columns', 'move_columns_head');
*/