<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
wow_load_styles() - enqueue CSS files
=================================================================================================================
*/
function wow_load_styles(){
	wp_enqueue_style( 'style' , WOW_URI.'/style.css', array(), '1.0', 'all' );
	
	if ( wow_option( 'enable-mobile-typography' ) == '1' ){
		wow_enqueue_default_fonts();
	}
	else{
		if ( !wp_is_mobile() ){
			wow_enqueue_default_fonts();
		}
	}
}
add_action( 'wp_enqueue_scripts' , 'wow_load_styles', 1 );

/*
=================================================================================================================
wow_add_default_fonts() - Add theme default fonts
=================================================================================================================
*/
function wow_add_default_fonts(){
	
	$body_font_arr = wow_option( 'body-typography' );
	$body_font = !empty(  $body_font_arr['font-family'] ) ? $body_font_arr['font-family'] : 'Roboto';		
	
	$heading_font_arr = wow_option( 'heading-typography' );
	$heading_font = !empty(  $heading_font_arr['font-family'] ) ? $heading_font_arr['font-family'] : 'Rubik';
	$heading_font_w = !empty(  $heading_font_arr['font-weight'] ) ? $heading_font_arr['font-weight'] : '500';
	
	if ( wow_option( 'enable-mobile-typography' ) == '1' ){
		$css = '
			body,.primary-font,.widget h2{font-family:'.$body_font.', Arial} 
			h1,h2,h3,h4,h5,h6,.secondary-font,.woocommerce-Price-amount,.woocommerce form .form-row label, #ad-post p{font-family:'.$heading_font.', Arial}
		';
	}
	else{
			
		if ( !wp_is_mobile() ){
			$css = '
				body,.primary-font,.widget h2{font-family:'.$body_font.', Arial} 
				h1,h2,h3,h4,h5,h6,.secondary-font,.woocommerce-Price-amount,.woocommerce form .form-row label, #ad-post p{font-family:'.$heading_font.', Arial; font-weight:'.$heading_font_w.'}
			';
		}
		else{
			$css = '.primary-font,.widget h2,body{font-family:-apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"}.secondary-font,h1,h2,h3,h4,h5,h6{font-family:-apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"}';
		}			
	}	
	

	echo '<style type="text/css">' . wp_kses_post( $css ) . '</style>';
}
add_action( 'wp_head','wow_add_default_fonts' );

/*
=================================================================================================================
wow_load_scripts() - enqueue js files
=================================================================================================================
*/
function wow_load_scripts(){
	wp_enqueue_script('jquery');

	wow_slick_enqueue();
	
	if ( wow_option( 'lazy-load' )  == '1' ){
		wp_enqueue_script( 'lazy', WOW_URI."/js/lazy.js", '', '', true );
	}
	
	wp_enqueue_script( 'scripts', WOW_URI."/js/scripts.js", '', '', true );
	
	wp_localize_script( 'scripts', 'ajax_var', array(
		'url' => admin_url( 'admin-ajax.php' ),
		'nonce' => wp_create_nonce( 'wow_count_downloads' ),
		'nonce_shares' => wp_create_nonce( 'wow_count_shares' ),
	 ));	
	 
	 $data = array(
		'url' => WOW_URI,
	);
	
	wp_localize_script( 'lazy', 'object_name', $data );
	 
}
add_action( 'wp_enqueue_scripts' , 'wow_load_scripts' , 1 );

/*
=================================================================================================================
wow_slick_enqueue() - enqueue slick only when necessary
=================================================================================================================
*/
function wow_slick_enqueue(){
	global $wp_query;
	
	$posts = is_array( $wp_query->posts ) ? $wp_query->posts : '';

	if ( is_array( $posts ) ){
		foreach( $posts as $post ){
			if ( get_post_format( $post->ID ) == 'gallery' ){
				wp_enqueue_script( 'slick', WOW_URI."/js/slick.min.js", '', '', true );
				continue;
			}
		}
	}
}

/*
=================================================================================================================
wow_gutenberg_gallery_enqueue() - enqueue CSS and JS if post has gallery gutenberg block
=================================================================================================================
*/
function wow_gutenberg_gallery_enqueue(){
		
	if ( is_singular('post') ){
			
		$post = get_post();	
		
		//backward compatibility - this function was introduced in Wordpress 5.0.0
		if ( function_exists( 'has_blocks' ) ){
			if ( has_blocks( $post->post_content ) ) {
				$blocks = parse_blocks( $post->post_content );
				foreach ( $blocks as  $block ){
					if( $block['blockName'] === 'core/gallery' ){
						wp_enqueue_style( 'simple-lightbox' , WOW_URI.'/css/simple-lightbox.min.css', array(), '1.0', 'all' );	
						wp_enqueue_script( 'simple-lightbox', WOW_URI."/js/simple-lightbox.min.js", '', '', true );
					}
				}
			}
		}
		else{
			wp_enqueue_style( 'simple-lightbox' , WOW_URI.'/css/simple-lightbox.min.css', array(), '1.0', 'all' );	
			wp_enqueue_script( 'simple-lightbox', WOW_URI."/js/simple-lightbox.min.js", '', '', true );			
		}
	//enqueue for widgets gallery
	
	}
}

add_action( 'get_footer','wow_gutenberg_gallery_enqueue',1 );
	

/*
=================================================================================================================
wow_widget_gallery_enqueue() - enqueue CSS and JS if widget has gallery
=================================================================================================================
*/
function wow_widget_gallery_enqueue(){
	$widgets = wp_get_sidebars_widgets();
	unset( $widgets['wp_inactive_widgets'] );
	foreach ( $widgets as $widget ){
		foreach ( $widget as $w ){
			if ( stripos ( $w, 'media_gallery'  ) !== false ){
				wp_enqueue_style( 'simple-lightbox' , WOW_URI.'/css/simple-lightbox.min.css', array(), '1.0', 'all' );	
				wp_enqueue_script( 'simple-lightbox', WOW_URI."/js/simple-lightbox.min.js", '', '', true );					
			}
		}
	}
}
add_action( 'get_footer','wow_widget_gallery_enqueue',1 );
/*
=================================================================================================================
wow_load_admin_styles() - enqueue the CSS files in admin
=================================================================================================================
*/
function wow_load_admin_styles() {
	wp_enqueue_style( 'admin-style' , WOW_URI.'/css/admin-style.css', array(), '1.0', 'all' ); 
}
add_action( 'admin_enqueue_scripts', 'wow_load_admin_styles' );

/*
=================================================================================================================
wow_load_admin_scripts() - enqueue the JS files in admin
=================================================================================================================
*/
function wow_load_admin_scripts() {
	wp_enqueue_script( 'admin-scripts-fribba' , WOW_URI.'/js/admin.js', '', '', true ); 
	wp_localize_script('admin-scripts-fribba', 'fribba_admin_data', array(
		'ajax_url' => esc_url(admin_url('admin-ajax.php')),
	));	
	wp_enqueue_script('modal', WOW_URI . '/js/modal.min.js', array('jquery'));
	wp_enqueue_style('modal', WOW_URI . '/css/modal.min.css');
}
add_action( 'admin_enqueue_scripts', 'wow_load_admin_scripts' );

function wow_enqueue_default_fonts(){

	$body_font_arr = wow_option( 'body-typography' );
	$body_font = !empty(  $body_font_arr['font-family'] ) ? $body_font_arr['font-family'] : 'Roboto';	
	$body_font_w = !empty(  $body_font_arr['font-weight'] ) ? $body_font_arr['font-weight'] : '400';	
	
	$heading_font_arr = wow_option( 'heading-typography' );
	$heading_font = !empty(  $heading_font_arr['font-family'] ) ? $heading_font_arr['font-family'] : 'Rubik';
	$heading_font_w = !empty(  $heading_font_arr['font-weight'] ) ? $heading_font_arr['font-weight'] : '500';

	wp_enqueue_style( 'wow-google-fonts', 'https://fonts.googleapis.com/css?family='.$heading_font.':'.$heading_font_w.'|'.$body_font.':'.$body_font_w.'&display=swap' );
}


/*
=================================================================================================================
wow_custom_css() - add custom CSS
=================================================================================================================
*/
function wow_custom_css(){
	$opts = get_option('fribba_options');
	
	$sticky_menu = $opts['sticky-menu'] == '1' ? true : false;
	$date_and_cat = $opts['date_and_cat'] == '1' ? true : false;
	$tagcloud_border = $opts['tagcloud_border'] == '1' ? true : false;
	$show_separator = $opts['show_separator'] == '1' ? true : false;
	
	$header_author_btn = $opts['header-author-btn'] == '1' ? true : false;
	$header_social_btn = $opts['header-social-btn'] == '1' ? true : false;
	$header_search_btn = $opts['header-search-btn'] == '1' ? true : false;
	
	$blog_placeholder = $opts['blog_placeholder'] == '1' ? true : false;
	
	$css = '<style>';
		$css .= !$sticky_menu ? '#theme-header.header-sticky{position:static}' : '';
		$css .= !$date_and_cat ? 'article .post-category, article .vertical-separator, article .author-date a:nth-of-type(2){display:none}' : '';
		$css .= !$tagcloud_border ? '.tagcloud a, .wp-block-tag-cloud a{border:none !important}' : '';
		$css .= !$show_separator ? '.main-separator{display:none !important} #sidebar, #sidebar .widget{border:none !important} #sidebar{padding-top:0;} .widget{padding-bottom:20px;margin-top:10px;} .widget_tag_cloud p{margin-bottom:0;} .widget h2{margin-bottom:20px;}' : '';
		
		$css .= !$header_author_btn ? '.author-list{display:none !important}' : '';
		$css .= !$header_social_btn ? '.social-holder{display:none !important}' : '';
		$css .= !$header_search_btn ? '.search-trigger-holder{display:none !important}' : '';
		$css .= $header_social_btn == 0 && $header_search_btn == 0 ? '.social-and-search{border:none !important}' : '';
		$css .= !$blog_placeholder  ? '.no-image .post-category, .no-image .views-and-downloads{position:static} article:hover .no-image .post-category{box-shadow:none} .no-image .views-and-downloads span{background-color:#f5f5f5} .no-image .views-and-downloads{display:inline-flex; margin-top:10px;}' : '';
		
	$css .= '</style>';
	
	echo $css;
}
add_action( 'wp_head' , 'wow_custom_css' );

























