<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/*
=================================================================================================================
wow_head_title() - SEO Title
=================================================================================================================
*/
function wow_head_title( $title ){

	$page_nr = get_query_var('paged') > 0 ?  get_query_var('paged') : '';
	$page_nr_title = get_query_var('paged') > 0 ?  __( ' - Page ','fribba' ) : '';	
	$blog = get_option( 'show_on_front' );

	/* For Posts Page */
	if ( wow_option( 'seo','enable-blog-seo' ) == '1' ){
		if ( is_home() ){
			$title = wow_option( 'seo','seo-blog-title' );
			if ( !empty ( $title ) ){		
				return esc_attr( stripslashes( $title ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr )  ;
			}
		}
	}

	/* For Homepage */
	if ( wow_option( 'seo','enable-homepage-seo' ) == '1' ){
		if ( is_front_page() ){
			$title = wow_option( 'seo','seo-title' );
			if ( !empty ( $title ) ){		
				return esc_attr( stripslashes( $title ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr )  ;
			}
		}
	}	

	/* For Shop */
	if ( class_exists( 'WooCommerce' ) ){
		if ( wow_option( 'seo','enable-woo-seo' ) == '1' ){
			if ( is_shop() ){
				$title = wow_option( 'seo','woo-seo-title' );
				if ( !empty ( $title ) ){		
					return esc_attr( stripslashes( $title ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr )  ;
				}
			}
		}
	}	

	if ( wow_option( 'seo','enable-posts-seo' ) == '1' ){

		/* For product categories */
		$product_categories = get_terms( array( 'taxonomy' => 'product_cat' ) );
		foreach ( $product_categories as $product_category ){
			if ( class_exists( 'WooCommerce' ) ){
				$title = get_term_meta( $product_category->term_id, 'seo-title', true );
				if( !empty( $title ) && is_product_category( $product_category->slug ) ){
					return esc_attr( stripslashes( $title ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr )  ;
				}
			}			
		}	
		
		/* For categories */
		$categories = get_terms( array( 'taxonomy' => 'category' , 'hide_empty' => 0  ) );
		foreach ( $categories as $category ){
			$term = get_category_by_slug( $category->slug );
			$title = get_term_meta( $term->term_id, 'seo-title', true );
			if( !empty( $title ) && is_category( $term->term_id ) ){
				return esc_attr( stripslashes( $title ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr )  ;
			}		
		}

		/* For product tags */
		$product_tags = get_terms( array( 'taxonomy' => 'product_tag' ) );
		foreach ( $product_tags as $product_tag ){
			if ( class_exists( 'WooCommerce' ) ){
				$title = get_term_meta( $product_tag->term_id , 'seo-title', true );
				if( !empty( $title ) && is_product_tag( $product_tag->slug ) ){
					return esc_attr( stripslashes( $title ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr )  ;
				}
			}			
		}	
		
		/* For tags */
		$tags = get_terms( array( 'taxonomy' => 'post_tag' ) );
		foreach ( $tags as $tag ){
			$title = get_term_meta( $tag->term_id , 'seo-title', true );
			if( !empty( $title ) && is_tag( $tag->term_id ) ){
				return esc_attr( stripslashes( $title ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr )  ;
			}		
		}	
		
		
		/* For posts and pages */
		if ( is_single() || is_page() ){
			global $post;
			$title = get_post_meta( $post->ID, 'seo-title', true );
			if( !empty( $title ) ){
				return esc_attr( stripslashes( $title ) );
			}
		}

	}	
	

}
add_filter( 'pre_get_document_title', 'wow_head_title' );


/*
=================================================================================================================
wow_seo_desc() - SEO Description and Keywords
=================================================================================================================
*/
function wow_seo_desc(){
	
	
	$page_nr = get_query_var('paged') > 0 ?  get_query_var('paged') : '';
	$page_nr_title = get_query_var('paged') > 0 ?  __( ' - Page ','fribba' ) : '';	
	
	/* For Posts Page */
	if ( wow_option( 'seo','enable-blog-seo' ) == '1' ){
		if ( is_home() ){
			$desc = wow_option( 'seo','seo-blog-desc' );
			if ( !empty ( $desc ) ){		
				echo '<meta name="description" content="'. esc_attr( stripslashes( $desc ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";
			}
		}
	}	
	
	/* For Homepage */
	if ( wow_option( 'seo','enable-homepage-seo' ) == '1' ){	
		if ( is_front_page() ){
			$desc = wow_option( 'seo','seo-desc' );
			if ( !empty ( $desc ) ){
				echo '<meta name="description" content="'. esc_attr( stripslashes( $desc ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";
			}
		}
	}
	
	/* For Shop */
	if ( class_exists( 'WooCommerce' ) ){
		if ( wow_option( 'seo','enable-woo-seo' ) == '1' ){
			if ( is_shop() ){
				$desc = wow_option( 'seo','woo-seo-desc' );
				if ( !empty ( $desc ) && wow_option( 'seo','enable-woo-seo' ) == '1' ){		
					echo '<meta name="description" content="'. esc_attr( stripslashes( $desc ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";
				}
			}
		}
	}	

	if ( wow_option( 'seo','enable-posts-seo' ) == '1' ){
		
		/* For product categories */
		$product_categories = get_terms( array( 'taxonomy' => 'product_cat' ) );
		foreach ( $product_categories as $product_category ){
			if ( class_exists( 'WooCommerce' ) ){
				$desc = get_term_meta( $product_category->term_id, 'seo-desc', true );
				if( !empty( $desc ) && is_product_category( $product_category->slug ) ){
					echo '<meta name="description" content="'. esc_attr( stripslashes( $desc ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";
				}
			}			
		}		

		
		/* For categories */
		$categories = get_terms( array( 'taxonomy' => 'category', 'hide_empty' => 0 ) );
		foreach ( $categories as $category ){
			$term = get_category_by_slug( $category->slug );
			$desc = get_term_meta( $term->term_id, 'seo-desc', true );
			if( !empty( $desc ) && is_category( $term->term_id ) ){
				echo '<meta name="description" content="'. esc_attr( stripslashes( $desc ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";
			}		
		}
		
		/* For product tags */
		$product_tags = get_terms( array( 'taxonomy' => 'product_tag' ) );
		foreach ( $product_tags as $product_tag ){
			if ( class_exists( 'WooCommerce' ) ){
				$desc = get_term_meta( $product_tag->term_id , 'seo-desc', true );
				if( !empty( $desc ) && is_product_tag( $product_tag->slug ) ){
					echo '<meta name="description" content="'. esc_attr( stripslashes( $desc ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";
				}
			}			
		}		
		
		/* For tags */
		$tags = get_terms( array( 'taxonomy' => 'post_tag' ) );
		foreach ( $tags as $tag ){
			$desc = get_term_meta( $tag->term_id , 'seo-desc', true );
			if( !empty( $desc ) && is_tag( $tag->term_id ) ){
				echo '<meta name="description" content="'. esc_attr( stripslashes( $desc ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";			
			}		
		}
		
		/* For posts and pages */
		if ( is_single() || is_page() ){
			global $post;
			$desc = get_post_meta( $post->ID, 'seo-desc', true );
			if( !empty( $desc ) ){
				echo '<meta name="description" content="'. esc_attr( stripslashes( $desc ) ) .'" />'."\n";
			}
		}
		
		if ( is_author() ){
			$desc = get_the_author_meta('description');
			if( !empty( $desc ) ){
				echo '<meta name="description" content="'. esc_attr( stripslashes( $desc ) ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";
			}		
		}
	
	}
	
	if ( wow_option( 'seo','enable-archive-seo' ) == '1' ){
		
		if ( is_day() ){
			$desc = !empty( wow_option( 'seo','seo-day-desc' ) ) ? wow_option( 'seo','seo-day-desc' ).' ' : 'Posts archives for day - ';
			if( !empty( $desc ) ){
				echo '<meta name="description" content="'. esc_attr( $desc ) . esc_attr( get_the_date('d').' '.get_the_date('F').' '.get_the_date('Y') ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";
			}			
		}		
		if ( is_month() ){
			$desc = !empty( wow_option( 'seo','seo-month-desc' ) ) ? wow_option( 'seo','seo-month-desc' ).' ' : 'Posts archives for month - ';
			if( !empty( $desc ) ){
				echo '<meta name="description" content="'. esc_attr( $desc ) . esc_attr( get_the_date('F').' '.get_the_date('Y') ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";
			}			
		}		
		if ( is_year() ){
			$desc = !empty( wow_option( 'seo','seo-year-desc' ) ) ? wow_option( 'seo','seo-year-desc' ).' ' : 'Posts archives for year - ';
			if( !empty( $desc ) ){
				echo '<meta name="description" content="'. esc_attr( $desc ) . esc_attr( get_the_date('Y') ).esc_attr( $page_nr_title ).esc_attr( $page_nr ).'" />'."\n";
			}			
		}
		
	}	
	
}
add_action( 'wp_head', 'wow_seo_desc', 1 );



/*
=================================================================================================================
wow_post_seo_defaults() - Default SEO Title / Description / for posts and page
=================================================================================================================
*/
function wow_post_seo_defaults( $post_ID ){
	
	//update title on post creation / update
	$title = get_post_meta( $post_ID, 'seo-title' , true );
	if ( empty ( $title ) && get_the_title( $post_ID ) != 'Auto Draft' ){
		update_post_meta( $post_ID, 'seo-title', get_the_title( $post_ID ) );
	}
	
	//update desc on post creation / update
	$desc = get_post_meta( $post_ID, 'seo-desc' , true );
	if ( empty ( $desc ) ){
		//remove shortcodes from meta description
		$excerpt = esc_attr( html_entity_decode( trim ( preg_replace( "~(?:\[/?)[^/\]]+/?\]~s", '', wow_excerpt( 160  , $post_ID ) ) ) ) );
		update_post_meta( $post_ID, 'seo-desc', $excerpt );
	}	
	
}

/*
=================================================================================================================
wow_term_seo_defaults() - Default SEO Title / Description / for tags
=================================================================================================================
*/
function wow_term_seo_defaults( $term_id, $tt_id, $taxonomy ){
	
	$tag = get_tag( $term_id );
	$tag_name = $tag->name;
	
	if ( $taxonomy == 'post_tag' ){
		//update seo title and desc on tag creation
		update_term_meta( $term_id, 'seo-title', 'Posts tagged - '.$tag_name );
		update_term_meta( $term_id, 'seo-desc', 'Posts containing tag - '. $tag_name . ' - ' . get_bloginfo( 'name' ) );
	}
}

#### run only if auto-seo is on ####
if ( wow_option( 'seo','auto-seo' ) == '1' ){
	add_action( 'save_post', 'wow_post_seo_defaults', 100 );
	add_action( 'create_term', 'wow_term_seo_defaults', 100, 3 );
}


/*
=================================================================================================================
wow_canonical() - canonical urls
=================================================================================================================
*/
function wow_canonical() {
 
    global $wp_query;

    $paged = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
    $max   = intval( $wp_query->max_num_pages );

	if ( is_home() || is_category() || is_day() || is_month() || is_year() || is_author() || is_tag() || is_archive() || is_tax() ) {

		//first page
		if ( $paged == 1 ){
			echo '<link rel="canonical" href="'.esc_url( get_pagenum_link( 1 ) ).'" />' . PHP_EOL;
			if ( $max > 1 ){
				echo '<link rel="next" href="'.esc_url( get_pagenum_link( $paged+1 ) ).'" />' . PHP_EOL;
			}
		}  
		//second page
		if ( $paged == 2 ){
			echo '<link rel="canonical" href="'.esc_url( get_pagenum_link( $paged ) ).'" />' . PHP_EOL;
			echo '<link rel="prev" href="'.esc_url( get_pagenum_link( 1 ) ).'" />' . PHP_EOL;
			if ( $max > 2 ){
				echo '<link rel="next" href="'.esc_url( get_pagenum_link( $paged+1 ) ).'" />' . PHP_EOL;
			}
		}
		//3rd page and above
		if ( $paged > 2 ){
			echo '<link rel="canonical" href="'.esc_url( get_pagenum_link( $paged ) ).'" />' . PHP_EOL;
			echo '<link rel="prev" href="'.esc_url( get_pagenum_link( $paged-1 ) ).'" />' . PHP_EOL;
			if ( $paged < $max ){
				echo '<link rel="next" href="'.esc_url( get_pagenum_link( $paged+1 ) ).'" />' . PHP_EOL;
			}
		}
	
	}
	if ( is_single() || is_page() ){
		echo '<link rel="canonical" href="'.esc_url( get_the_permalink() ).'" />' . PHP_EOL;	
	}

}

#### run only if extra seo is on ####
if ( wow_option( 'seo','enable-extra' ) == '1' ){
	add_action( 'wp_head','wow_canonical',1 );
	add_action( 'wp_head','wow_meta_google_robots',1 );
	add_action( 'wp_head','wow_graph', 2 );
}

// https://yoast.com/robots-meta-changes-for-google/
function wow_meta_google_robots(){
	echo '<meta name="robots" content="max-snippet:-1, max-image-preview:large, max-video-preview:-1"/>' . PHP_EOL;
}

//add schema graph
function wow_graph(){
	
	global $wp_query, $post;
	
	$graph = $primary_image = $author = $page_image = array();
	$sameAs = wow_output_social_author( true );
	$paged = get_query_var( 'paged' );
	$user_id = get_the_author_meta('ID');
	$user = get_userdata( $user_id );

	//image
	$id_img = get_post_thumbnail_id( $post->ID );
	$image = wp_get_attachment_image_src( $id_img, 'full' );

	//output everywhere
	$graph[] = array(
			'@type' => 'WebSite',
			'@id' => esc_url( get_home_url() ).'/#website',
			'url' => esc_url( trailingslashit( get_home_url() ) ),
			'name' => esc_attr( get_bloginfo('name') ),
			'potentialAction' => array(
				'@type' => 'SearchAction',
				'target' => esc_url( get_home_url() ).'/?s={search_term_string}',
				'query-input' => 'required name=search_term_string',
			),
	);	
	
	//build for archive
	if ( is_home() || ( function_exists( 'is_shop' ) && is_shop() ) ){
		
		$graph[] = array(
			'@type' => 'CollectionPage',
			'@id' => esc_url( get_pagenum_link( $paged ) ).'#webpage',
			'url' => esc_url( get_pagenum_link( $paged ) ),
			'inLanguage' => esc_attr( get_bloginfo( 'language' ) ),
			'name' => esc_attr( wp_get_document_title() ),
			'isPartOf' => array(
				'@id' => esc_url( get_home_url() ).'/#website',
			),
			'description' => esc_attr( get_bloginfo('description') )	
		);	
	}

	if ( is_single() || is_page() ){

		if ( has_post_thumbnail() ){

			$graph[] = array(
				'@type' => 'ImageObject',
				'@id' => esc_url( get_the_permalink() ).'#primaryimage',
				'url' => esc_url( $image[0] ),
				'width' =>  intval( esc_attr( $image[1] ) ),
				'height' => intval( esc_attr( $image[2] ) ),
			);

			$primary_image = array(
				'@id' => esc_url( get_the_permalink() ).'#primaryimage',
			);
			
		}
		else{
			//get first image from post if any
			if ( wow_catch_that_image() ){
				$graph[] = array(
					'@type' => 'ImageObject',
					'@id' => esc_url( get_the_permalink() ).'#primaryimage',
					'url' => esc_url( wow_catch_that_image() ),
				);
			
				$primary_image = array(
					'@id' => esc_url( get_the_permalink() ).'#primaryimage',
				);
				
			}
			
		}
	}	
	
	//build for archive
	if ( is_category() || is_tag() || is_tax() || is_day() || is_month() || is_year() ){
		$graph[] = array(
			'@type' => 'CollectionPage',
			'@id' => esc_url( get_pagenum_link( $paged ) ).'#webpage',
			'url' => esc_url( get_pagenum_link( $paged ) ),
			'inLanguage' => esc_attr( get_bloginfo( 'language' ) ),
			'name' => esc_attr( wp_get_document_title() ),
			'isPartOf' => array(
				'@id' => esc_url( get_home_url() ).'/#website',
			),
		);	
	}
	
	//if is single
	if ( is_single() ){
		
		if ( get_post_type() == 'post' ){
			$author = array(
				'@id' => esc_url( get_home_url() ).'/#/schema/person/'. esc_attr( wp_hash( $user->user_login . $user_id ) ),
			);			
		}
		
		$graph[] = array(
			'@type' => 'WebPage',
			'@id' => esc_url( get_the_permalink() ).'#webpage',
			'url' => esc_url( get_the_permalink() ),
			'inLanguage' => get_bloginfo( 'language' ),
			'name' => esc_attr( wp_get_document_title() ),
			'isPartOf' => array(
				'@id' => esc_url( get_home_url() ).'/#website',
			),
			'primaryImageOfPage' => $primary_image, //safely escaped above
			'datePublished' => esc_attr( mysql2date( DATE_W3C, $post->post_date_gmt, false ) ),
			'dateModified'  => esc_attr( mysql2date( DATE_W3C, $post->post_modified_gmt, false ) ),
			'author' => $author,
		);		

		if ( get_post_type() == 'post' ){
			$graph[] = array(
				'@type' => array(
					'Person',
				),
				'@id' => get_home_url().'/#/schema/person/'. esc_attr( wp_hash( $user->user_login . $user_id ) ),
				'name' => esc_attr( $user->display_name ),
				'image' => array(
					'@type' => 'ImageObject',
					'@id' => esc_url( trailingslashit( get_home_url() ) ).'#authorlogo',
					'url' => get_avatar_url( $user_id ),
					'caption' => esc_attr( $user->display_name ),
				),
				'description' => esc_attr( get_the_author_meta( 'description' ) ),
				'sameAs' => $sameAs, //safely escaped in wow_output_social_author() which is -> $sameAs
			);
		}
		
	}
	
	//if is page
	if ( is_page() ){
		
		if ( has_post_thumbnail() || wow_catch_that_image() ){
			$page_image = array(
				'@id' => esc_url( get_the_permalink() ).'#primaryimage',
			);
		}
		
		$graph[] = array(
			'@type' => 'WebPage',
			'@id' => esc_url( get_the_permalink() ).'#webpage',
			'url' => esc_url( get_the_permalink() ),
			'inLanguage' => get_bloginfo( 'language' ),
			'name' => esc_attr( wp_get_document_title() ),
			'isPartOf' => array(
				'@id' => esc_url( get_home_url() ).'/#website',
			),
			'primaryImageOfPage' => $page_image,
			'datePublished' => esc_attr( mysql2date( DATE_W3C, $post->post_date_gmt, false ) ),
			'dateModified'  => esc_attr( mysql2date( DATE_W3C, $post->post_modified_gmt, false ) ),
		);		
	}
	
	//if is author
	if ( is_author() ){
		
		$graph[] = array(
			'@type' => 'ProfilePage',
			'@id' => esc_url( get_author_posts_url( $user_id ) ).'#webpage',
			'url' => esc_url( get_author_posts_url( $user_id ) ),
			'inLanguage' => get_bloginfo( 'language' ),
			'name' => esc_attr( wp_get_document_title() ),
			'isPartOf' => array(
				'@id' => esc_url( get_home_url() ).'/#website',
			),
		);
		
		$graph[] = array(
			'@type' => array(
				'Person',
			),
			'@id' => get_home_url().'/#/schema/person/'. esc_attr( wp_hash( $user->user_login . $user_id ) ),
			'name' => esc_attr( $user->display_name ),
			'image' => array(
				'@type' => 'ImageObject',
				'@id' => esc_url( trailingslashit( get_home_url() ) ).'#authorlogo',
				'url' => get_avatar_url( $user_id ),
				'caption' => esc_attr( $user->display_name ),
			),
			'description' => esc_attr( get_the_author_meta( 'description' ) ),
			'sameAs' => $sameAs, //safely escaped in wow_output_social_author() which is -> $sameAs
			'mainEntityOfPage' => array(
				'@id' => esc_url( get_author_posts_url( $user_id ) ).'#webpage',
			),
		);
			
			
	}	

	//remove empty array values
	$graph = array_map( 'array_filter', $graph );
	$graph = array_filter( $graph );

	$output = array(
		'@context' => 'https://schema.org',
		'@graph'   => $graph,
	);
	
	$flags = 0;
	$flags = ( $flags | JSON_UNESCAPED_SLASHES );
	

	//var_dump($graph);
	
	//safe to output > all escaped above
	echo "<script type='application/ld+json' class=\"fribba-schema-graph\">" . wp_json_encode( $output , $flags ) . '</script>' . "\n";	
	
}


function wow_catch_that_image() {
  global $post, $posts;
  $first_img = '';
  ob_start();
  ob_end_clean();
  $output = preg_match_all( '/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches );
  $first_img =  !empty ( $matches [1] ) ? $matches [1][0] : '';
  if( !empty( $first_img ) ){
	return $first_img;
  }
  return false;
 
}