<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
wow_option - Retrieve an option / or false if not set
=================================================================================================================
*/
if ( !function_exists ( 'wow_option' ) ){
	function wow_option( $value , $from_array_value = NULL ){
		$options = get_option( 'fribba_options' );
		if ( !empty ( $options ) ){
			if ( isset ( $options[ $value ] ) ) {
					if ( $from_array_value ){
						return $options[ $value ][ $from_array_value ];
					}
				return $options[ $value ];
			}
		}
		return false;
	}
}
/*
=================================================================================================================
wow_get_gallery_urls - Retrieve url for each attachemnt id
=================================================================================================================
*/
function wow_get_gallery_urls( $value ){
	$attachments = array();
	$options = get_option( 'fribba_options' );
	if ( !empty ( $options ) ){
		if ( isset ( $options[ $value ] ) ) {
			$pieces = explode ( ',' , $options[ $value ] );
			foreach ( $pieces as $piece ){
				$attachments []=  wp_get_attachment_url( $piece );
			}
			return $attachments;
		}
	}
	return false;
}

/*
=================================================================================================================
wow_get_gallery_urls - Retrieve url for each attachemnt id
=================================================================================================================
*/
function wow_get_gallery_urls_meta( $value , $size ){
	$attachments = array();
	$gallery = get_post_meta( get_the_ID(), $value, true );
	if ( !empty ( $gallery ) ){
		$pieces = explode ( ',' , $gallery );
		foreach ( $pieces as $piece ){
			$attachment_src = wp_get_attachment_image_src( $piece, $size );
			$attachments[$piece] = $attachment_src[0];
		}
		return $attachments;

	}
	return false;
}

/*
=================================================================================================================
wow_get_grid - Get the grid
=================================================================================================================
*/
 
function wow_get_grid( $real = false ){
	if ( is_single() ){
		return '4';
	}
	if ( wow_option( 'blog-layout' ) == 'grid-4' ){
		if ( $real ){
			return '4';
		}
		return '3';
	}	
	elseif ( wow_option( 'blog-layout' ) == 'grid-3' ){
		if ( $real ){
			return '3';
		}
		return '4';
	}	
	elseif ( wow_option( 'blog-layout' ) == 'grid-2' ){
		if ( $real ){
			return '2';
		}
		return '6';
	}	
	else{
		if ( $real ){
			return '1';
		}
		return '12';
	}
}

/*
=================================================================================================================
wow_get_thumb_size - Determine thumb size
=================================================================================================================
*/
 
function wow_get_thumb_size(){
	if ( wow_option( 'blog-layout' ) == 'grid-1' ){
		return 'blog-classic';
	}		
	else{
		return 'grid';
	}
}

/*
=================================================================================================================
wow_get_single_thumb_size - Determine thumb size for single
=================================================================================================================
*/
 
function wow_get_single_thumb_size(){
	$meta_layout      	    = get_post_meta( get_the_ID(), 'blog-single-layout', true );
	$meta_thumb      	    = get_post_meta( get_the_ID(), 'blog-single-thumb', true );
	
	$thumb  = $meta_thumb  != 'default' ? $meta_thumb  : wow_option( 'blog-single-thumb' );
	$layout = $meta_layout != 'default' ? $meta_layout : wow_option( 'blog-single-layout' );
	
	if ( $thumb == 'original' ){
		return 'full';
	}
	
	if ( $layout == 'sidebar' ){
		return 'blog-classic';
	}		
	else{
		return 'full-single';
	}
}

/*
=================================================================================================================
wow_post_thumb - output post thumb / video / audio html
=================================================================================================================
*/
function wow_post_thumb( $is_loop = true,  $is_single = false , $is_widget = false , $show_details = true , $echo_link = true ){
	
	$post_format = get_post_format();
	$post_type = get_post_type();
	$blog_placeholder = wow_option('blog_placeholder');
					
	//get size
	if ( $is_widget == true ){
		$size = 'widget';
	}
	if ( $is_single == true ){
		$size = wow_get_single_thumb_size();
	}
	if ( $is_loop == true ){
		$size = wow_get_thumb_size();
	}
	
	//get grid
	if ( $is_widget == true ){
		$grid = 'widget';
	}
	if ( $is_single == true ){
		$meta_layout      	    = get_post_meta( get_the_ID(), 'blog-single-layout', true );
		$layout = $meta_layout != 'default' ? $meta_layout : wow_option( 'blog-single-layout' );
		$grid = $layout == 'sidebar' ? '1' : 'full-single';
	}
	if ( $is_loop == true ){
		$grid = wow_get_grid(1);
	}
	/**
	 * Standard post format
	 *
	 */
	if ( $post_format  ==  false ) { 
		if ( has_post_thumbnail() ) {
			$image = get_the_post_thumbnail_url( get_the_ID() , $size );
			$alt_title = get_post( get_post_thumbnail_id() )->post_excerpt ? get_post( get_post_thumbnail_id() )->post_excerpt : get_post( get_post_thumbnail_id() )->post_title;
	?>
	
		<div class="post-thumb">
			<?php if ( $show_details ) { ?>
			<div class="post-category secondary-font">
				<?php wow_first_cat_link(); ?>
			</div>
			<?php } ?>
			<?php if ( $post_type == 'page' ) { ?>
			<div class="post-category secondary-font">
				<a href="<?php echo esc_url( get_the_permalink() ); ?>" class="category-link page-link"><?php echo esc_html( $post_type ); ?></a>
			</div>
			<?php } ?>			
			<?php if ( $echo_link ) { ?><a href="<?php echo esc_url( get_the_permalink() ) ?>"><?php } ?>
			<?php if ( wow_option( 'lazy-load' )  == '1' ) { ?>
				<img class="cover-image lazyload" src="<?php echo esc_url( WOW_URI.'/images/placeholder-'.esc_attr( $grid ).'.png' ); ?>" alt="<?php echo esc_attr( $alt_title ); ?>" data-src="<?php echo esc_url( $image ); ?>">
			<?php } else { ?>
				<img class="cover-image visible" src="<?php echo esc_url( $image ) ?>" alt="<?php echo esc_attr( $alt_title ); ?>">
			<?php } ?>
			<?php if ( $echo_link ) { ?></a><?php } ?>
			<?php if ( $show_details ) { ?>
			<div class="views-and-downloads">
				<?php wow_download_ouput(); ?>
				<?php wow_views_ouput();  ?>
			</div>
			<?php } ?>
		</div>
	
<?php 
		}
		
		//default thumb
		else{ ?>
		<?php if ( $echo_link ) { ?>
		<div class="post-thumb no-image">
			<?php if ( $show_details ) { ?>
			<div class="post-category secondary-font">
				<?php wow_first_cat_link(); ?>
			</div>
			<?php } ?>			
			<?php if ( $post_type == 'page' ) { ?>
			<div class="post-category secondary-font">
				<a href="<?php echo esc_url( get_the_permalink() ); ?>" class="category-link page-link"><?php echo esc_html( $post_type ); ?></a>
			</div>
			<?php }

				if( $blog_placeholder == '1'){ ?>
					<a href="<?php echo esc_url( get_the_permalink() ) ?>" class="">
						<img src="<?php echo esc_url( WOW_URI.'/images/placeholder-'.esc_attr( $grid ).'.png' ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
					</a>										
				<?php } ?>

			<?php if ( $show_details ) { ?>
			<div class="views-and-downloads">
				<?php wow_download_ouput(); ?>
				<?php wow_views_ouput();  ?>
			</div>
			<?php } ?>
		</div>
		<?php } ?>
<?php		}
		
	} // END Standard post format
	
	/**
	 * Video post format
	 *
	 */	
	elseif ( $post_format  ==  'video' ){
		$video_id = $video_url = '';
		$video_type  = get_post_meta( get_the_ID(), 'video-type', true );
		$youtube_url = get_post_meta( get_the_ID(), 'youtube', true );
		$vimeo_url = get_post_meta( get_the_ID(), 'vimeo', true );
		$custom_code = get_post_meta( get_the_ID(), 'custom', true );
		if ( $video_type == 'youtube' && !empty ( $youtube_url ) ){
			if ( preg_match( '%(?:youtube(?:-nocookie)?\.com/(?:[^/]+/.+/|(?:v|e(?:mbed)?)/|.*[?&]v=)|youtu\.be/)([^"&?/ ]{11})%i', $youtube_url, $match )) {
				$video_id = $match[1];
				$video_url = 'https://www.youtube.com/embed/'.esc_attr( $video_id );
			}
		}
		elseif( $video_type == 'vimeo' && !empty ( $vimeo_url ) ){
			if ( preg_match('/(\d+)/', $vimeo_url, $match ) ){
				$video_id = $match[1];
				$video_url = 'https://player.vimeo.com/video/'.esc_attr( $video_id );
			}
		}	
		elseif( $video_type == 'custom' && !empty ( $custom_code ) ){
			if ( preg_match('/src="([^"]+)"/', $custom_code, $match ) ){
				$video_url = $match[1];
			}
		}
		
		if ( !empty( $video_url ) ){ ?>
		
			<div class="post-thumb">
				<?php if ( wow_option( 'lazy-load' )  == '1' ) { ?>
					<iframe class="lazyload" width="100%" data-src="<?php echo esc_url( $video_url ); ?>" frameborder="0" allowfullscreen></iframe>
				<?php } else { ?>
					<iframe width="100%" src="<?php echo esc_url( $video_url ); ?>" frameborder="0" allowfullscreen></iframe>
				<?php } ?>
			</div>	
			
		<?php }
		
		//default thumb
		else{ ?>
		<?php if ( $echo_link ) { ?>
		<div class="post-thumb">
			<?php if ( $show_details ) { ?>
			<div class="post-category secondary-font">
				<?php wow_first_cat_link(); ?>
			</div>
			<?php } ?>
			<a href="<?php echo esc_url( get_the_permalink() ) ?>" class="">
				<img src="<?php echo esc_url( WOW_URI.'/images/placeholder-'.esc_attr( $grid ).'.png' ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
			</a>
			<?php if ( $show_details ) { ?>
			<div class="views-and-downloads">
				<?php wow_download_ouput(); ?>
				<?php wow_views_ouput();  ?>
			</div>
			<?php } ?>
		</div>
		<?php } ?>
<?php		}
	
	} // END Video post format

	/**
	 * Audio post format
	 *
	 */	
	elseif ( $post_format  ==  'audio' ){
	
		$soundcloud_url = get_post_meta( get_the_ID(), 'soundcloud', true );
		$custom_code = wp_oembed_get( $soundcloud_url );
		if ( preg_match('/src="([^"]+)"/', $custom_code, $match ) ) {
			$soundcloud_url = $match[1];
			$soundcloud_url = str_replace('&', '&amp;', $soundcloud_url );
		}

		if ( !empty ( $soundcloud_url ) ) { ?>
			
			<div class="post-thumb">
				<?php if ( wow_option( 'lazy-load' )  == '1' ) { ?>
					<iframe class="lazyload"  width="100%" frameborder="0" data-src="<?php echo esc_url( $soundcloud_url ); ?>"></iframe>
				<?php } else { ?>
					<iframe width="100%" scrolling="no" frameborder="0" src="<?php echo esc_url( $soundcloud_url ); ?>"></iframe>
				<?php } ?>
			</div>	
			
		<?php }
		
		//default thumb
		else{ ?>
		<?php if ( $echo_link ) { ?>
		<div class="post-thumb">
			<?php if ( $show_details ) { ?>
			<div class="post-category secondary-font">
				<?php wow_first_cat_link(); ?>
			</div>
			<?php } ?>
			<a href="<?php echo esc_url( get_the_permalink() ) ?>" class="">
				<img src="<?php echo esc_url( WOW_URI.'/images/placeholder-'.esc_attr( $grid ).'.png' ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
			</a>
			<?php if ( $show_details ) { ?>
			<div class="views-and-downloads">
				<?php wow_download_ouput(); ?>
				<?php wow_views_ouput();  ?>
			</div>
			<?php } ?>
		</div>
		<?php } ?>
<?php		}
	
	} // END Audio post format
	
	/**
	 * Gallery post format
	 *
	 */		
	elseif( $post_format  ==  'gallery' ){
	
		$post_thumb = array();
			
		if ( has_post_thumbnail() ) {
			$post_thumb_id = get_post_thumbnail_id();
			$post_thumb = array( $post_thumb_id => get_the_post_thumbnail_url( get_the_ID() , $size ) );
		}
	
		
			
		$gallery = !empty ( wow_get_gallery_urls_meta( 'post-gallery', $size ) ) ? wow_get_gallery_urls_meta( 'post-gallery', $size ) : array();
		$final_gallery = $post_thumb + $gallery;
		
		if ( !empty( $final_gallery ) ) {
	
	 ?>

		<div class="post-thumb">
			<?php if ( $show_details ) { ?>
			<div class="post-category secondary-font">
				<?php wow_first_cat_link(); ?>
			</div>
			<?php } ?>
			<?php if ( wow_option( 'lazy-load' )  == '1' ) { ?>
				<div class="slick">
					<?php foreach ( $final_gallery as $image_id => $image ) { 
						$get_post = get_post( $image_id );
						$alt_title = $get_post->post_excerpt ? $get_post->post_excerpt : $get_post->post_title;
					?>
					<div>
						<img data-lazy="<?php echo esc_url( $image ); ?>" alt="<?php echo esc_attr( $alt_title ); ?>" src="<?php echo esc_url( WOW_URI.'/images/placeholder-'.esc_attr( $grid ).'.png' ); ?>">						
					</div>
					<?php } ?>
				</div>
			<?php } else { ?>
				<div class="slick">
					<?php foreach ( $final_gallery as $image_id => $image ) {
						$get_post = get_post( $image_id );
						$alt_title = $get_post->post_excerpt ? $get_post->post_excerpt : $get_post->post_title;
						?>
					<div>
						<img class="cover-image visible" alt="<?php echo esc_attr( $alt_title ); ?>" src="<?php echo esc_url( $image ) ?>">				
					</div>
					<?php } ?>
				</div>
			<?php } ?>
			<?php if ( $show_details ) { ?>
			<div class="views-and-downloads">
				<?php wow_download_ouput(); ?>
				<?php wow_views_ouput();  ?>
			</div>
			<?php } ?>
		</div>		
		
	<?php
		}
				
		else{ ?>
		<?php if ( $echo_link ) { ?>
		<div class="post-thumb">
			<?php if ( $show_details ) { ?>
			<div class="post-category secondary-font">
				<?php wow_first_cat_link(); ?>
			</div>
			<?php } ?>
			<a href="<?php echo esc_url( get_the_permalink() ) ?>" class="">
				<img src="<?php echo esc_url( WOW_URI.'/images/placeholder-'.esc_attr( $grid ).'.png' ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
			</a>
			<?php if ( $show_details ) { ?>
			<div class="views-and-downloads">
				<?php wow_download_ouput(); ?>
				<?php wow_views_ouput();  ?>
			</div>
			<?php } ?>
		</div>
		<?php } ?>
<?php		}
	
	} // END Gallery post format
	
	/**
	 * Any other post format
	 *
	 */		
		else{  ?>
		<?php if ( $echo_link ) { ?>
		<div class="post-thumb">
			<?php if ( $show_details ) { ?>
			<div class="post-category secondary-font">
				<?php wow_first_cat_link(); ?>
			</div>
			<?php } ?>
			<a href="<?php echo esc_url( get_the_permalink() ) ?>" class="">
				<img src="<?php echo esc_url( WOW_URI.'/images/placeholder-'.esc_attr( $grid ).'.png' ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
			</a>
			<?php if ( $show_details ) { ?>
			<div class="views-and-downloads">
				<?php wow_download_ouput(); ?>
				<?php wow_views_ouput();  ?>
			</div>
			<?php } ?>
		</div>
		<?php } ?>
<?php		}

	
} // END wow_post_thumb()

/*
=================================================================================================================
wow_get_post_views - Get post views count
=================================================================================================================
*/
function wow_get_post_views() {
    $count = get_post_meta( get_the_ID(), 'post-views-count', true );
    return $count;
}

/*
=================================================================================================================
wow_set_post_views - Set post views count
=================================================================================================================
*/
function wow_set_post_views() {
    $key = 'post-views-count';
    $post_id = get_the_ID();
    $count = (int) get_post_meta( $post_id, $key, true );
    $count++;
    update_post_meta( $post_id, $key, $count );
}

/*
=================================================================================================================
wow_first_cat_link - Get url of first category of a post
=================================================================================================================
*/
function wow_first_cat_link(){
	$category = get_the_category();
	
	if ( empty ( $category ) ){
		return false;
	}

	$count_cat = count( $category );
	
	if ( $count_cat > 1 ){
		echo '<a class="category-link bg-cat-'.esc_attr( $category[0]->slug ).'" href="'. esc_url( get_category_link( $category[0]->term_id ) ) .'"> <span>'. esc_html( $category[0]->name ) .'</span></a>'; 				
		echo '<a class="category-link bg-cat-'.esc_attr( $category[1]->slug ).'" href="'. esc_url( get_category_link( $category[1]->term_id ) ) .'"> <span>'. esc_html( $category[1]->name ) .'</span></a>'; 				
	}
	else{
		echo '<a class="category-link bg-cat-'.esc_attr( $category[0]->slug ).'" href="'. esc_url( get_category_link( $category[0]->term_id ) ) .'"> <span>'. esc_html( $category[0]->name ) .'</span></a>'; 
	}
}

/*
=================================================================================================================
wow_css_cat_bg - Output css for custom category background
=================================================================================================================
*/
function wow_css_cat_bg(){
	$output = '';
	
	$categories = get_terms( array( 'taxonomy' => 'category' ) );
	foreach ( $categories as $category ){
		$term = get_category_by_slug( $category->slug );
		$bg = get_term_meta( $term->term_id, 'color', true );
		
		//defaults
		$bg_color = ( !empty ( $bg["background-color"] ) ) ? $bg["background-color"] : wow_get_main_color(1);
		$bg_gr_color = ( !empty ( $bg["background-gradient-color"] ) ) ? $bg["background-gradient-color"] : wow_get_main_color(2);
		$bg_gr_dir = ( !empty ( $bg["background-gradient-direction"] ) ) ? $bg["background-gradient-direction"] : 'to right';
		
		//only output if colors is different from main color(s)
		if ( $bg_color != wow_get_main_color(1) || $bg_gr_color != wow_get_main_color(2) ){
			$output .= '.bg-cat-'.esc_attr( $category->slug ).'{ background-image:linear-gradient( '.esc_attr( $bg_gr_dir ).', '.esc_attr( $bg_color ).' , '.esc_attr( $bg_gr_color ).' ) }';
		}
	}
	if ( $output ){
		echo '<style type="text/css">' .esc_attr ( $output ). '</style>';
	}
	
}
add_action( 'wp_head','wow_css_cat_bg',11 );

/*
=================================================================================================================
wow_get_main_color_1 - Get main theme colors ( param $color int - possible values 1 or 2 )
=================================================================================================================
*/
function wow_get_main_color( int $color  ){
	if ( wow_option('color-scheme') == 'skins' ){
		if ( wow_option('skin-colors') == 'set1' ){
			if ( $color == 1 ){
				return '#FF416C';
			}
			else{
				return '#9b539f';
			}
		}
		elseif ( wow_option('skin-colors') == 'set2' ){
			if ( $color == 1 ){
				return '#000000';
			}
			else{
				return '#111111';
			}
		}
	}
	else{
		if ( $color == 1 ){
			return !empty( wow_option('custom-colors','color-1') ) ? wow_option('custom-colors','color-1') : '#FF416C';
		}
		else{
			return !empty( wow_option('custom-colors','color-2') ) ? wow_option('custom-colors','color-2') : '#9b539f';
		}
	}
}
/*
=================================================================================================================
wow_add_class_to_category - Add custom link class to the_category()
=================================================================================================================

function wow_add_class_to_category( $thelist, $separator, $parents ){
    $class_to_add = 'color-2';
    return str_replace('<a href="', '<a class="' . $class_to_add . '" href="', $thelist);
}
add_filter('the_category','wow_add_class_to_category',10,3);
*/

/*
=================================================================================================================
wow_cats - Add custom link class to the_category()
=================================================================================================================
*/
function wow_categories( $id ){
	$categories = get_the_category( $id );
	echo '<div class="post-category single secondary-font">';
	wow_download_ouput();
	foreach ( $categories as $category ){
		$url = get_category_link( $category->term_id );
		echo '<a class="category-link bg-cat-'.esc_attr( $category->slug ).'" href="'. esc_url( $url ) .'"> '. esc_html( $category->name ) .'</span></a>';
	}
	echo '</div>';
}


/*
=================================================================================================================
wow_count_downloads() - Count freebie downloads - for ajax
=================================================================================================================
*/
add_action( 'wp_ajax_wow_count_downloads', 'wow_count_downloads' );
add_action( 'wp_ajax_nopriv_wow_count_downloads', 'wow_count_downloads' );

function wow_count_downloads() {
	
	$nonce = $_POST['nonce'];
	if ( ! wp_verify_nonce( $nonce, 'wow_count_downloads' ) ){
		die ( 'cheatin?');
	}
	
	$post_id = sanitize_text_field( $_POST['post_id'] );   
	
	$download_counter = get_post_meta( $post_id, 'download-counter', true );
	if( !$download_counter ) {
		$download_counter = 0;
	}
   
	$response = update_post_meta( $post_id, 'download-counter', ++$download_counter );
	
	if( $response ){
		die('success');
	}

    die('fail');
}


/*
=================================================================================================================
wow_count_shares() - Count freebie downloads - for ajax
=================================================================================================================
*/
add_action( 'wp_ajax_wow_count_shares', 'wow_count_shares' );
add_action( 'wp_ajax_nopriv_wow_count_shares', 'wow_count_shares' );

function wow_count_shares() {
	
	$nonce = $_POST['nonce'];
	if ( ! wp_verify_nonce( $nonce, 'wow_count_shares' ) ){
		die ( 'cheatin?');
	}
	
	$post_id = sanitize_text_field( $_POST['post_id'] );   
	
	$share_counter = get_post_meta( $post_id, 'share-counter', true );
	if( !$share_counter ) {
		$share_counter = 0;
	}
   
	$response = update_post_meta( $post_id, 'share-counter', ++$share_counter );
	
	if( $response ){
		die('success');
	}

    die('fail');
}

/*
=================================================================================================================
wow_get_download_views - Get post downlaods count
=================================================================================================================
*/
function wow_get_download_views() {
    $count = get_post_meta( get_the_ID(), 'download-counter', true );
    return $count;
}

/*
=================================================================================================================
wow_download_ouput - Output html number of downloads
=================================================================================================================
*/
function wow_download_ouput( $after_text = '' ){
	$downloads = wow_get_download_views();
	if ( $downloads > 0 ){ ?>
	<span class="downloads" aria-label="<?php echo esc_attr__( 'Number of downloads','fribba' ); ?>"><?php wow_svg( 'file-download-line'  ) ; ?><?php echo esc_html( $downloads ); ?><?php echo ' '.esc_html( $after_text ); ?></span>

<?php		
	}
}
add_filter( 'downloads_text', 'wow_download_ouput', 10, 3 );

/*
=================================================================================================================
wow_views_ouput - Output html number of post views
=================================================================================================================
*/
function wow_views_ouput( $after_text = '' ){
	$views = wow_get_post_views();
	if ( $views > 0 ){ ?>
	<span><?php wow_svg( 'article-line'  ) ; ?><?php echo esc_html( $views ); ?><?php echo ' '.esc_html( $after_text ); ?></span>

<?php		
	}
}

/*
=================================================================================================================
wow_output_social - Output social
=================================================================================================================
*/
 
function wow_output_social(){
	$socials = array( 
		'facebook' => 'facebook',
		'twitter' => 'twitter',
		'youtube' => 'youtube',
		'linkedin' => 'linkedin',
		'pinterest' => 'pinterest',
		'dribbble' => 'dribbble',
		'instagram' => 'instagram',
		'behance' => 'behance',
	);
	
	foreach ( $socials as $key => $value ){
		$get_social = wow_option( $key );
		if ( !empty( $get_social ) ){
				echo '<li class="social-holder"><a href="'.esc_url( $get_social ).'" aria-label="'.esc_attr( $key ).'" target="_blank">'. wow_brands_svg( esc_html ( $value ) , false ).'</a></li>'; 
		}
	}		
}

/*
=================================================================================================================
wow_output_social_author - Output social for author
=================================================================================================================
*/
 
function wow_output_social_author( $return = false ){
	
	$data = array();
	
	$socials = array( 
		'website' => 'globe',
		'facebook' => 'facebook',
		'twitter' => 'twitter',
		'youtube' => 'youtube',
		'linkedin' => 'linkedin',
		'pinterest' => 'pinterest',
		'dribbble' => 'dribbble',
		'instagram' => 'instagram',
		'behance' => 'behance',
	);

	$user_id   = get_the_author_meta('ID');
	
	foreach ( $socials as $key => $value ){
		$get_social = get_user_meta( $user_id, $key, true );
		if ( !empty( $get_social ) && $return ){
			$data []=  $get_social;
		}
		if ( !empty( $get_social ) && $return == false ){
			echo '<li><a href="'.esc_url( $get_social ).'" aria-label="'.esc_attr( $key ).'" target="_blank">'. wow_brands_svg( esc_html ( $value ) , false ).'</a></li>'; 
		}
	}
	
	if ( $return ){
		return $data;
	}
	
}
/*
=================================================================================================================
wow_author_has_social - Determine if an author have any social enabled from user profile options
=================================================================================================================
*/
 
function wow_author_has_social(){
	$socials = array( 
		'website',
		'facebook',
		'twitter',
		'youtube',
		'linkedin',
		'pinterest',
		'dribbble',
		'instagram',
		'behance',
	);

	$user_id   =  get_the_author_meta('ID');
	
	foreach ( $socials as $social ){
		$get_social = get_user_meta( $user_id, $social, true );
		if ( !empty( $get_social ) ){
			return true;
		}
	}
	return false;	
}


/*
=================================================================================================================
wow_author_avatar - Get author avatar
=================================================================================================================
*/
function wow_author_avatar(){
	$author_id = get_the_author_meta('ID'); 
	$avatar = get_avatar( $author_id );  
	return get_avatar( $author_id, 80 , '', get_the_author_meta('nickname')  );
}

/*
=================================================================================================================
wow_author_info - Get author info
=================================================================================================================
*/
function wow_author_info( $value ){
	$user_id = get_the_author_meta('ID');
	$get_user_meta = get_user_meta( $user_id );
	return $get_user_meta[$value][0];
}



/*
=================================================================================================================
wow_output_authors - Output authors list
=================================================================================================================
*/
function wow_output_authors(){
	$users = get_users( array('role__in' => array('contributor', 'author', 'editor', 'administrator')  ) );
	if ( !empty( $users ) && is_array ( $users ) ){ ?>
		<div class="nav">
			<ul class="menu">
				<li class="menu-item menu-item-has-children author"><a class="author-dropdown"><?php wow_svg( 'group-fill' ) ; ?></a>
					<ul class="sub-menu">
						<?php foreach ( $users as $user ){ 
							$post_count = count_user_posts( $user->ID  );
							if ( $post_count > 0 ) {
						
						?>			
						<li class="menu-item">
							<a href="<?php echo esc_url( get_author_posts_url( $user->ID ) ); ?>" class="menu-link sub-menu-link"><?php echo esc_html( $user->nickname ); ?></a>
						</li>

<?php 
							} // end if post count
						} //end foreach
?>
					</ul>
				</li>
			</ul>
		</div>	
 		
<?php 	} // end if ! empty users
		
}

/*
=================================================================================================================
wow_render_post_ad - Render post ad
=================================================================================================================
*/
function wow_render_post_ad(){
	
	//var_dump(wow_option( 'lazy-disable-ad' ),"sssss");
	
	if ( wow_option( 'ads','enable-post-ad' ) == 1 ){
		//banner ad
		if ( wow_option( 'ads','post-ad-type') == 'banner' ){
			if ( !empty( wow_option( 'ads','post-ad-url' ) ) && !empty( wow_option( 'ads','post-ad-media' ) ) ){
				if ( wow_option( 'lazy-load' )  == '1' &&  !wow_option( 'lazy-disable-ad' ) == 1 ){  ?>
				
				<div class="post-ad">
					<a href="<?php echo esc_url( wow_option( 'ads','post-ad-url' ) ); ?>"><img class="lazyload" src="data:image/gif;base64,R0lGODdhAQABAPAAAMPDwwAAACwAAAAAAQABAAACAkQBADs=" data-src="<?php echo esc_url(  wow_option( 'ads','post-ad-media' ) ); ?>" alt="<?php echo esc_attr__('Post Ad','fribba'); ?>"></a>
				</div>
				<?php if ( !empty ( wow_option( 'ads','post-ad-after' ) ) ) { ?><p><?php echo esc_html( wow_option( 'ads','post-ad-after' ) ); ?></p><?php } ?>
<?php			}
				else{ ?>
				
				<div class="post-ad">
					<a href="<?php echo esc_url( wow_option( 'ads','post-ad-url' ) ); ?>"><img src="<?php echo esc_url( wow_option( 'ads','post-ad-media' ) ); ?>" alt="<?php echo esc_attr__('Post Ad','fribba'); ?>"></a>
				</div>
				<?php if ( !empty ( wow_option( 'ads','post-ad-after' ) ) ) { ?><p><?php echo esc_html( wow_option( 'ads','post-ad-after' ) ); ?></p><?php } ?>	
<?php			}
			}
		} // end if banner ad
		
		//code ad
		elseif( wow_option( 'ads','post-ad-type') == 'code' && !empty( wow_option( 'ads','post-ad-code' ) ) ) { ?>
		<div class="post-ad adsense<?php if ( wow_option( 'lazy-load' )  == '1' &&  !wow_option( 'lazy-disable-ad' ) == 1 ){ echo ' ads-lazy'; } ?>">
			<?php echo do_shortcode( wow_option( 'ads','post-ad-code' ) ); ?>
		</div>
<?php		}
	}
}

/*
=================================================================================================================
wow_render_header_ad - Render header ad
=================================================================================================================
*/
function wow_render_header_ad(){
	if ( wow_option( 'ads','enable-header-ad' ) == 1 ){
		//banner ad
		if ( wow_option( 'ads','header-ad-type') == 'banner' ){
			if ( !empty( wow_option( 'ads','header-ad-url' ) ) && !empty( wow_option( 'ads','header-ad-media' ) ) ){
				if ( wow_option( 'lazy-load' )  == '1' ){  ?>
				
				<div class="header-ad">
					<a href="<?php echo esc_url( wow_option( 'ads','header-ad-url' ) ); ?>"><img class="lazyload" src="data:image/gif;base64,R0lGODdhAQABAPAAAMPDwwAAACwAAAAAAQABAAACAkQBADs=" data-src="<?php echo esc_url( wow_option( 'ads','header-ad-media' ) ); ?>" alt="<?php echo esc_attr__('Header Ad','fribba'); ?>"></a>
				</div>
					
<?php			}
				else{ ?>
				
				<div class="header-ad">
					<a href="<?php echo esc_url( wow_option( 'ads','header-ad-url' ) ); ?>"><img src="<?php echo esc_url( wow_option( 'ads','header-ad-media' ) ); ?>" alt="<?php echo esc_attr__('Header Ad','fribba'); ?>"></a>
				</div>
					
<?php			}
			}
		} // end if banner ad
		
		//code ad
		elseif( wow_option( 'ads','header-ad-type') == 'code' && !empty( wow_option( 'ads','header-ad-code' ) ) ) { ?>
		<div class="header-ad adsense">
			<?php echo do_shortcode( wow_option( 'ads','header-ad-code' ) ); ?>
		</div>
<?php		}
	}
}

/*
=================================================================================================================
wow_render_above_post_ad - Render above post head ad
=================================================================================================================
*/
function wow_render_above_post_ad(){
	if ( wow_option( 'ads','enable-single1-ad' ) == 1 ){
		//banner ad
		if ( wow_option( 'ads','single1-ad-type') == 'banner' ){
			if ( !empty( wow_option( 'ads','single1-ad-url' ) ) && !empty( wow_option( 'ads','single1-ad-media' ) ) ){
				if ( wow_option( 'lazy-load' )  == '1' ){  ?>
				
				<div class="above-post-ad">
					<a href="<?php echo esc_url( wow_option( 'ads','single1-ad-url' ) ); ?>"><img class="lazyload" src="data:image/gif;base64,R0lGODdhAQABAPAAAMPDwwAAACwAAAAAAQABAAACAkQBADs=" data-src="<?php echo esc_url( wow_option( 'ads','single1-ad-media' ) ); ?>" alt="<?php echo esc_attr__('Above post content Ad','fribba'); ?>"></a>
				</div>
					
<?php			}
				else{ ?>
				
				<div class="above-post-ad">
					<a href="<?php echo esc_url( wow_option( 'ads','single1-ad-url' ) ); ?>"><img src="<?php echo esc_url( wow_option( 'ads','single1-ad-media' ) ); ?>" alt="<?php echo esc_attr__('Above post content Ad','fribba'); ?>"></a>
				</div>
					
<?php			}
			}
		} // end if banner ad
		
		//code ad
		elseif( wow_option( 'ads','single1-ad-type') == 'code' && !empty( wow_option( 'ads','single1-ad-code' ) ) ) { ?>
		<div class="above-post-ad adsense">
			<?php echo do_shortcode( wow_option( 'ads','single1-ad-code' ) ); ?>
		</div>
<?php		}
	}
}


/*
=================================================================================================================
wow_render_bellow_post_ad - Render bellow post head ad
=================================================================================================================
*/
function wow_render_bellow_post_ad(){
	if ( wow_option( 'ads','enable-single2-ad' ) == 1 ){
		//banner ad
		if ( wow_option( 'ads','single2-ad-type') == 'banner' ){
			if ( !empty( wow_option( 'ads','single2-ad-url' ) ) && !empty( wow_option( 'ads','single2-ad-media' ) ) ){
				if ( wow_option( 'lazy-load' )  == '1' ){  ?>
				
				<div class="bellow-post-ad">
					<a href="<?php echo esc_url( wow_option( 'ads','single2-ad-url' ) ); ?>"><img class="lazyload" src="data:image/gif;base64,R0lGODdhAQABAPAAAMPDwwAAACwAAAAAAQABAAACAkQBADs=" data-src="<?php echo esc_url( wow_option( 'ads','single2-ad-media' ) ); ?>" alt="<?php echo esc_attr__('Above post content Ad','fribba'); ?>"></a>
				</div>
					
<?php			}
				else{ ?>
				
				<div class="bellow-post-ad">
					<a href="<?php echo esc_url( wow_option( 'ads','single2-ad-url' ) ); ?>"><img src="<?php echo esc_url( wow_option( 'ads','single2-ad-media' ) ); ?>" alt="<?php echo esc_attr__('Above post content Ad','fribba'); ?>"></a>
				</div>
					
<?php			}
			}
		} // end if banner ad
		
		//code ad
		elseif( wow_option( 'ads','single2-ad-type') == 'code' && !empty( wow_option( 'ads','single2-ad-code' ) ) ) { ?>
		<div class="bellow-post-ad adsense">
			<?php echo do_shortcode( wow_option( 'ads','single2-ad-code' ) ); ?>
		</div>
<?php		}
	}
}
/*
=================================================================================================================
wow_body_class - Add custom body class
=================================================================================================================
*/
add_filter( 'body_class', 'wow_body_class' );
function wow_body_class( $classes ) {
    
	//single layout - from theme options or post meta
	$meta_layout      	    = get_post_meta( get_the_ID(), 'blog-single-layout', true );
	$layout = $meta_layout != 'default' ? $meta_layout : wow_option( 'blog-single-layout' );		
	
	if ( ( wow_option( 'blog-layout' ) == 'grid-1' || wow_option( 'blog-layout' ) == 'grid-2' ) && ( is_home() || is_category() || is_archive() || is_day() || is_month() || is_year() || is_tag() || is_author() ) ) {
        $classes[] = 'has-sidebar';
    }
	if ( $layout == 'sidebar' && is_single() ){
		$classes[] = 'has-sidebar';
	}	
	if ( $layout == 'full' && is_single() ){
		$classes[] = 'full';
	}
    return $classes;
}

/*
=================================================================================================================
wow_subscribe_bg - Add subscribe background if empty in theme options
=================================================================================================================
*/
add_filter( 'wp_head', 'wow_subscribe_bg' );
function wow_subscribe_bg( ) {
	
	$bg_color = wow_option( 'bg-subscribe', 'background-color');
	$bg = wow_option( 'bg-subscribe','background-image');
	if (  empty( $bg_color ) && empty( $bg['url'] ) ) {
		echo '<style type="text/css">.subscribe{ background-image:url( '.esc_url ( WOW_URI.'/images/bg-subscribe.jpg' ).' ) }</style>';
	}

   
}

/*
=================================================================================================================
wow_get_edd_downloads - Retrieve all easy digital downloads
=================================================================================================================
*/
function wow_get_edd_downloads(){
	$download = array( 0 => 'Select download' );
	$args = array( 'post_type' => 'download' );
	$query = new WP_Query( $args );
	if( $query->have_posts() ) {
		while( $query->have_posts() ) {
			$query->the_post();
			$download[get_the_ID()] = get_the_title(); 
		}
	}
	wp_reset_postdata();
	if ( class_exists( 'Easy_Digital_Downloads' ) ){
		return $download;
	}
	return false;
	
}

/*
=================================================================================================================
wow_enable_threaded_comments() - Threaded Comments
=================================================================================================================
*/
function wow_enable_threaded_comments(){
	if ( !is_admin() ) {
		if ( is_singular() && comments_open() && ( get_option( 'thread_comments' ) == 1 ) ) {
			wp_enqueue_script('comment-reply');
		}
	}
}
add_action( 'get_header', 'wow_enable_threaded_comments');

/*
=================================================================================================================
wow_get_the_post_id() - Return the post/page id inside or outside the loop
=================================================================================================================
*/
function wow_get_the_post_id() {
  if ( in_the_loop() ) {
       $post_id = get_the_ID();
  } else {
       global $wp_query;
       $post_id = $wp_query->get_queried_object_id();
         }
  return $post_id;
}


/*
=================================================================================================================
wow_build_cat_itemprop() - Build category breacrumbs
=================================================================================================================
*/
function wow_build_cat_itemprop() {
    $breadcrumbs = array();
    $category_count = 0;
    $parent_arrive = 0;
	
	//return early if attachemnt
	if ( is_attachment() ){ return false; }
	
	if (is_single()) {
        $post_data = get_queried_object();
        $breadcrumbs[$category_count]['id'] = $post_data->ID;
        $breadcrumbs[$category_count]['name'] = $post_data->post_title;
        $category_count++;
        $current_category = get_the_category();
        $current_category_id = $current_category[0]->term_id;
        $category = get_category($current_category_id);
    } else {
        $category = get_category(get_query_var('cat'));
    }
    $breadcrumbs[$category_count]['id'] = $category->term_id;
    $breadcrumbs[$category_count]['name'] = $category->name;
    $category_count++;
    while( $parent_arrive == 0 ) {
        if ($category->category_parent == 0) {
          $parent_arrive = 1;
        } else {
          $breadcrumbs[$category_count]['id'] = $category->category_parent;
          $category = get_category($category->category_parent);
          $breadcrumbs[$category_count]['name'] = $category->name;
        }
      $category_count++;
    }
    $breadcrumbs = array_reverse($breadcrumbs);
    return $breadcrumbs;
}

/*
=================================================================================================================
wow_cat_breadcrumb() - Output category breacrumbs itemprop
=================================================================================================================
*/
function wow_cat_breadcrumb(){
	//return early if attachemnt
	if ( is_attachment() ){ return false; }
	
	$breadcrumbs = wow_build_cat_itemprop(); ?>
<ul itemscope itemtype="http://schema.org/BreadcrumbList" class="breadcrumb theme">
	  <li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">
      <a itemprop="item" href="<?php echo esc_url( site_url() ); ?>">
        <span itemprop="name"><?php echo esc_attr__( 'Home','fribba' ); ?></span>
      </a>
		  <meta itemprop="position" content="1" />
		</li>
		<li>&nbsp;&nbsp;&#187;&nbsp;&nbsp;</li>
	
	<?php 
	if ( is_single() ) { array_pop( $breadcrumbs ); } 
	$page_nr = get_query_var('paged') > 0 ?  get_query_var('paged') : '';
	$page_nr_title = get_query_var('paged') > 0 ?  __( ' &nbsp;&nbsp;&#187;&nbsp;&nbsp; Page ','fribba' ) : '';  
	?>
	
    <?php
	$counter = 1;
	foreach ( $breadcrumbs as $breadcrumb_index => $breadcrumb ) { ?>
	 <?php if ( $counter > 1 ) { ?>
		<li>&nbsp;&nbsp;&#187;&nbsp;&nbsp;</li>
	 <?php } $counter++; ?>	       
	  <li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">
        <a itemprop="item" href="<?php echo esc_url( get_category_link($breadcrumb['id'] ) ); ?>">
          <span itemprop="name"><?php echo esc_attr( $breadcrumb['name'] ); ?></span>
        </a>
        <meta itemprop="position" content="<?php echo esc_attr( $breadcrumb_index ) + 2; ?>" />
		<?php echo esc_attr( $page_nr_title ) ; echo esc_attr( $page_nr ); ?>
      </li>
<?php   } ?>
		<?php if ( is_single() ){ ?>
		  <li>
			&nbsp;&nbsp;&#187;&nbsp;&nbsp;<?php the_title(); ?>
		  </li>		
	<?php	} ?>
</ul>

<?php }


/*
=================================================================================================================
wow_breadcrumb() - Breadcrumb navigation
=================================================================================================================
*/
function wow_breadcrumb() {
	if ( !is_front_page() ) {
	
	echo '<ul class="breadcrumb theme">';
	echo '<li><a href="';
	echo esc_url( home_url()  );
	echo '">';
	echo esc_html__( 'Home','fribba' );
	echo '</a></li>' . "&nbsp;&nbsp;&#187;&nbsp;&nbsp;";
	
	if ( is_day() ) {
		echo '<li>'.esc_html( get_the_time('d') ).' '.esc_html( get_the_time('F') ).' '.esc_html( get_the_time('Y') ).'</li>';
	} elseif ( is_month() ) {
		echo '<li>'.esc_html( get_the_time('F') ).' '.esc_html( get_the_time('Y') ).'</li>';
	} elseif ( is_year() ) {
		echo'<li>'. esc_html( get_the_time('Y') ).'</li>';
	} elseif ( is_tag() ){
		echo '<li>'.esc_html( single_tag_title( '',false ) ).'</li>';
	}
	 elseif ( is_single() ) {
		//the_category(' / ');
			//echo "&nbsp;&nbsp;&#187;&nbsp;&nbsp;";
			//the_title();
	} elseif ( is_page() ) {
		echo '<li>'.esc_html( get_the_title() ).'</li>';
	} elseif ( is_search() ) {
		echo '<li>'.esc_html__( 'Search results for ','fribba' );
		echo esc_html( the_search_query() ).'</li>';
	}
	echo '</ul>';
	}
}

/*
=================================================================================================================
wow_open_graph() - Open graph for social networks
=================================================================================================================
*/
function wow_open_graph(){

global $wp;

$title = get_the_title();
$site_title = get_bloginfo('name');
$description = !empty ( get_the_excerpt() ) ? get_the_excerpt() : $title;
$url = home_url( $wp->request );
$locale = get_locale();
$image = !empty ( wow_option( 'logo-image', 'url' ) ) ?  wow_option( 'logo-image', 'url' ) : '';
$type = 'article';

if( is_home() ){
	$title = $site_title;
	$description = !empty( get_bloginfo('description') ) ? get_bloginfo('description') : $title;
	$url = site_url();
	$type = 'website';
}  

if( is_archive() ){
	$title = get_the_archive_title();
	$description = !empty( term_description() ) ?  term_description() : $title;
	$type = !is_author() ? 'category' : 'author';
}

if ( is_singular() ){
	$image = has_post_thumbnail() ? get_the_post_thumbnail_url() : '';
}

$title 		 = html_entity_decode( strip_tags ( $title ) ) ;
$description = html_entity_decode( strip_tags ( $description ) ) ;

echo'
<meta property="og:title" content="'. esc_attr( $title ) .'" />
<meta property="og:description" content="'. esc_attr( $description ) .'" />
<meta property="og:type" content="'. esc_attr( $type ) .'" />
<meta property="og:url" content="'. esc_url( $url ) .'" />
<meta property="og:image" content="'. esc_url( $image ) .'" />	
<meta property="og:locale" content="'. esc_attr( $locale ) .'" />	
<meta property="og:site_name" content="'. esc_attr( $site_title ) .'" />

<meta name="twitter:card" content="summary_large_image" />
<meta name="twitter:description" content="'. esc_attr( $description ) .'" />
<meta name="twitter:title" content="'. esc_attr( $title ) .'" />
<meta name="twitter:image" content="'. esc_url( $image ) .'" />
';
}
add_action( 'wp_head','wow_open_graph', 9 );

/*
=================================================================================================================
wow_output_social_share() - Output social share
=================================================================================================================
*/
function wow_output_social_share(){
global $post;
//post thumbnail
$post_thumbnail_arr = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full-single' );
$post_thumbnail = $post_thumbnail_arr[0];
?>
<div class="social-share-holder">
<ul class="social-share"><!-- social-share -->			
	<li>
		<a target="_blank" data-post-id="<?php echo( esc_attr( $post->ID ) );?>" href="<?php echo esc_url( 'https://www.facebook.com/sharer/sharer.php?u='.urlencode( get_permalink() ) ); ?>" aria-label="<?php esc_attr_e( 'Share article to Facebook','fribba' ); ?>" class="facebook">
			<?php wow_brands_svg( 'facebook',true ) ; ?>
		</a>
	</li>
			
	<li>
		<a target="_blank" data-post-id="<?php echo( esc_attr( $post->ID ) );?>" href="<?php echo esc_url( 'https://twitter.com/intent/tweet?text='.urlencode( get_the_title() ).'&amp;url='.urlencode( get_permalink() ) ); ?>" aria-label="<?php esc_attr_e( 'Share article to Twitter','fribba' ); ?>" class="twitter">
			<?php wow_brands_svg( 'twitter',true ) ; ?>
		</a>
	</li>
			
	<li>
		<a target="_blank" data-post-id="<?php echo( esc_attr( $post->ID ) );?>" href="<?php echo esc_url( 'https://pinterest.com/pin/create/button/?url=' . urlencode( get_permalink() ) . '&amp;description=' . urlencode( get_the_title() ) . ( esc_attr($post_thumbnail ) ? '&amp;media=' . urlencode( esc_attr( $post_thumbnail ) ) : '' ) ); ?>" aria-label="<?php esc_attr_e( 'Share article to Pinterest','fribba' ); ?>" class="pinterest">
			<?php wow_brands_svg( 'pinterest',true ) ; ?>
		</a>
	</li>
			
	<li>
		<a target="_blank" data-post-id="<?php echo( esc_attr( $post->ID ) );?>" href="<?php echo esc_url( 'https://www.linkedin.com/shareArticle?mini=true&url='.urlencode( get_permalink() ).'&amp;title='.urlencode( get_the_title() ) ); ?>&amp;summary=<?php echo esc_attr( urlencode( get_the_excerpt() ) ); ?>" aria-label="<?php esc_attr_e( 'Share article to LinkedIn','fribba' ); ?>" class="linkedin">
				<?php wow_brands_svg( 'linkedin',true ) ; ?>			
			</a>
	</li>	
	
	<li>
		<a target="_blank" data-post-id="<?php echo( esc_attr( $post->ID ) );?>" href="mailto:?subject=<?php echo esc_attr( urlencode( get_the_title() ) ); ?>&body=<?php echo esc_url( get_permalink() ); ?>" aria-label="<?php esc_attr_e( 'Share article to mail','fribba' ); ?>" class="mail">
				<?php wow_brands_svg( 'mail',true ) ; ?>			
			</a>
	</li>
</ul><!--/ social-share -->
</div>

<?php 
}

/*
=================================================================================================================
wow_freebies() - Output freebies box
=================================================================================================================
*/
function wow_freebies(){
global $wp_query;	?>
<?php if ( wow_option( 'enable-freebies' ) == '1' ) { ?>
	<?php if ( is_home() || is_tax() || is_category() || is_tag() || is_author() ) { ?>
	<div class="count-articles">
		<?php if (  wow_option( 'freebies-counter' ) == 'animated' ) { ?>
			<h2 data-count="<?php echo intval( esc_attr( $wp_query->found_posts ) ); ?>">1</h2>
		<?php } else { ?>
			<h2><?php echo intval( esc_html( $wp_query->found_posts ) ); ?></h2>
		<?php } ?>
		<h3 class="primary-font">
			<?php if ( $wp_query->found_posts > 1  ) { ?>
				<?php echo esc_html( wow_option( 'freebies-plural' ) ); ?>
			<?php } else { ?>
				<?php echo esc_html( wow_option( 'freebies-singular' ) ); ?>
			<?php } ?>
		</h3>
	</div>
	<?php } ?>
<?php }
 }

/*
=================================================================================================================
wow_is_home_or_front() - Check if home or front page
=================================================================================================================
*/ 
function wow_is_home_or_front(){
	if ( is_front_page() ){
		return true;
	}
	if ( is_home() ){
		return true;
	}
}

/*
=================================================================================================================
Function wow_hex() - convert hex 2 rgba
=================================================================================================================
*/
function wow_hex( $hex, $alpha = 1 ){
	$hex = str_replace('#', '', $hex);
	$r = $g = $b = 0;

	switch(strlen($hex)){
		case 3:
			list($r, $g, $b) = str_split($hex);
			$r = hexdec($r.$r);
			$g = hexdec($g.$g);
			$b = hexdec($b.$b);
			break;
		case 6:
			list($r1, $r2, $g1, $g2, $b1, $b2) = str_split($hex);
			$r = hexdec($r1.$r2);
			$g = hexdec($g1.$g2);
			$b = hexdec($b1.$b2);
			break;
		default:
			break;
	}

	return 'rgba('.$r.', '.$g.', '.$b.', '.$alpha.')';
}

/*
=================================================================================================================
wow_colors() - generate custom css colors
=================================================================================================================
*/
function wow_colors( $main_color1, $main_color2, $body_color, $heading_color, $gradient_color1, $gradient_color2 , $gradient_color3 , $gradient_color4 , $body_bg_color1 = false, $body_bg_color2 = false, $body = true ){
	
	$output = '
		body,
		.body-color,
		.pagination a,
		.tagcloud a,
		ul.tags a{
			color:'.esc_attr( $body_color ).'; /* Body color */
		}

		h1, h1 a,
		h2, h2 a,
		h3, h3 a,
		h4, h4 a,
		h5, h5 a,
		h6, h6 a,
		.widget a,
		.menu > .menu-item > a,
		.sub-menu a,
		.widget h2,
		header .logo h1,
		.comment-reply a,
		.subscribe p
		/* article:hover .post-category .category-link */{
			color:'.esc_attr( $heading_color ).';
		}
		.mobile-trigger.is-active .mobile-trigger-inner,
		.mobile-trigger.is-active .mobile-trigger-inner::before,
		.mobile-trigger.is-active .mobile-trigger-inner::after,
		.mobile-trigger-inner, 
		.mobile-trigger-inner::before, 
		.mobile-trigger-inner::after,
		pre, code{
			background-color:'.esc_attr( $heading_color ).';
		}
		td, th,
		input[type="search"],
		input[type="text"],
		input[type="email"],
		input[type="password"],
		input[type="url"],
		input[type="number"],
		input[type=tel],
		textarea,
		select,
		.subscribe,
		.author-box,
		body .wp-block-table.is-style-stripes td,
		.comment-container,
		.breadcrumb-navigation,
		#sidebar .widget,
		#ad-post p{
			border-color:'.wow_hex( $heading_color, .2 ).';
		}
		article .separator,
		.articles .separator,
		article .vertical-separator,
		.article-single .vertical-separator,
		header#theme-header::after,
		.separator.single,
		.main-separator,
		.post-widget:after{
			background-color:'.esc_attr( wow_hex( $heading_color, .2 ) ).';
		}
		.tagcloud a,
		ul.tags a{
			border-color:'.esc_attr( wow_hex( $heading_color, .3 ) ).';
		}
		.search-trigger.mobile svg{
			fill:'.esc_attr( $heading_color ).';
		}

		/* Theme main color 1 */

		a,
		.color-1,
		.widget .color-1,
		.widget a:hover,
		.sub-menu .current-menu-item > a,
		.sub-menu a:hover,
		.menu > .menu-item > a:hover,
		.menu > .menu-item:hover > a,
		.menu > .current-menu-item > a,
		.menu > .current-menu-ancestor > a,
		ul.tags a:hover,
		.comment-date{
			color:'.esc_attr( $main_color1 ).';
		}
		.bg-color-1,
		.pagination a:hover,
		.pagination li.active a,
		.single .pagination span.current,
		.category-count span,
		input[type="submit"],
		button,
		#after-footer .social-and-search,
		.author-box .social-and-search,
		.wp-block-quote::before,
		.wp-block-pullquote::before,
		blockquote::before,
		.widget .line{
			background-color:'.esc_attr( $main_color1 ).';
		}
		.author-list:hover,
		.social-and-search:hover{
			border-color:'.esc_attr( $main_color1 ).';
		}		
		.social-and-search,
		.author-list,
		.articles .sticky .post-thumb,
		.tagcloud a:hover,
		.tags a:hover{
			border-color:'.esc_attr( wow_hex( $main_color1, .4 ) ).';
		}
		.social-and-search svg,
		.author-list svg,
		.author-date svg{
			fill:'.esc_attr( wow_hex( $main_color1, .4 ) ).';
		}
		header .social-and-search a:hover svg,
		header .author-list a:hover svg,
		header .author-date a:hover svg,
		li.author:hover > a.author-dropdown > svg{
			fill:'.esc_attr( wow_hex( $main_color1, 1 ) ).';
		}

		/* Theme main color 2 */
		a:hover,
		.color-2,
		.widget .color-2{
			color:'.esc_attr( $main_color2 ).';
		}
		button:hover,
		.bg-color-2,
		input[type="submit"]:hover{
			background-color:'.esc_attr( $main_color2 ).';
		}
		.subscribe .icon-holder svg,
		.views-and-downloads svg{
			fill:'.esc_attr( $main_color2 ).';
		}

		/* Gradient color 1 */
		footer#footer,
		.count-articles,
		.single .post-category span.downloads{
			background-image: linear-gradient(to right,'.esc_attr( $gradient_color1 ).','.esc_attr( $gradient_color2 ).');
		}
		/* Gradient color 2 */
		.category-link{
			background-image: linear-gradient( to right, '.esc_attr( $gradient_color3 ).' , '.esc_attr( $gradient_color4 ).' );
		}
	';
	
	if ( $body ){
		$output .= '		
			/* Body gradient */
			body{
				background-image: linear-gradient( to right,'.esc_attr( $body_bg_color1 ).','.esc_attr( $body_bg_color2 ).' );
			}
		';		
	}
	
	return $output;
	
}

/*
=================================================================================================================
wow_colors_output() - output custom css colors
=================================================================================================================
*/
function wow_colors_output(){
	
	/* skin colors */
	if ( wow_option( 'color-scheme' ) == 'skins' ){
		if ( wow_option( 'skin-colors' ) == 'set1' ){
			echo '<style type="text/css">' .wow_colors( '#FF416C', '#9b539f', '#5c6279', '#0e1638', '#6441a5', '#2a0845' , '#FF416C', '#9b539f', '#ff5f6d', '#ffc371' ). '</style>';
		}		
		elseif ( wow_option( 'skin-colors' ) == 'set2' ){
			echo '<style type="text/css">' .wow_colors( '#2c3e50', '#3498db', '#5c6279', '#0e1638', '#00c6ff', '#0072ff' , '#FF416C', '#9b539f', '#454655', '#d7d2cc' ). '</style>';
		}		
		elseif ( wow_option( 'skin-colors' ) == 'set3' ){
			echo '<style type="text/css">' .wow_colors( '#2c3e50', '#FF5722', '#5c6279', '#0e1638', '#ff754a', '#ff754a' , '#FF5722', '#FF5722', '#353032', '#d2c0ac' ). '</style>';
		}
	}
	
	/* custom colors */
	elseif( wow_option( 'color-scheme' ) == 'custom' ){
		$main_color1 		= !empty( wow_option( 'custom-colors','color-1' ) ) ? wow_option( 'custom-colors','color-1' ) : '#FF416C';
		$main_color2 		= !empty( wow_option( 'custom-colors','color-2' ) ) ? wow_option( 'custom-colors','color-2' ) : '#9b539f';
		$body_color 		= !empty( wow_option( 'custom-colors','color-3' ) ) ? wow_option( 'custom-colors','color-3' ) : '#5c6279';
		$heading_color 		= !empty( wow_option( 'custom-colors','color-4' ) ) ? wow_option( 'custom-colors','color-4' ) : '#0e1638';
		$gradient_color1 	= !empty( wow_option( 'custom-colors','color-5' ) ) ? wow_option( 'custom-colors','color-5' ) : '#6441a5';
		$gradient_color2 	= !empty( wow_option( 'custom-colors','color-6' ) ) ? wow_option( 'custom-colors','color-6' ) : '#2a0845';
		$gradient_color3 	= !empty( wow_option( 'custom-colors','color-7' ) ) ? wow_option( 'custom-colors','color-7' ) : '#FF416C';
		$gradient_color4 	= !empty( wow_option( 'custom-colors','color-8' ) ) ? wow_option( 'custom-colors','color-8' ) : '#9b539f';
		
		/* only output if there is a color change */
		if ( $main_color1 != '#FF416C' ||  $main_color2 != '#9b539f' ||  $body_color != '#5c6279' ||  $heading_color != '#0e1638' ||  $gradient_color1 != '#6441a5' ||  $gradient_color2 != '#2a0845' || $gradient_color3 != '#FF416C' ||  $gradient_color4 != '#9b539f'  ){
			echo '<style type="text/css">' .wow_colors( $main_color1, $main_color2, $body_color, $heading_color , $gradient_color1 , $gradient_color2 , $gradient_color3 , $gradient_color4 , false, false, false ). '</style>';
		}
	}
}
add_action('wp_head','wow_colors_output');

/*
=================================================================================================================
wow_favicon() - adds favicon
=================================================================================================================
*/
function wow_favicon(){
	if ( wow_option('favicon','url' ) ) { echo "\n"; ?>
<link href="<?php echo esc_url( wow_option('favicon','url' ) ); ?>" rel="icon" type="image/png" />
	<?php } 
}
add_action( 'wp_head','wow_favicon' );

/*
=================================================================================================================
wow_custom_css_js() - return custom css / js code from theme options and print it to head
=================================================================================================================
*/
function wow_custom_css_js(){
	if ( !empty( wow_option( 'css-editor' ) ) ){
		echo 
'<style id="theme-custom-css">' . wow_option( 'css-editor' ) . '</style>';
	}	
	if ( !empty( wow_option( 'js-editor' ) ) ){
		echo wow_option( 'js-editor' ); //safe
	}
}
add_action( 'wp_head','wow_custom_css_js' );


/*
=================================================================================================================
wow_tracking_code() - Add tracking code to footer
=================================================================================================================
*/
function wow_tracking_code(){
	if ( !empty( wow_option( 'tracking-code' ) ) ){
		echo  wow_option( 'tracking-code' );
	}
}
add_action( 'wp_footer','wow_tracking_code' );

/*
=================================================================================================================
wow_output_social_shares_number() - Output number of shares for an article
=================================================================================================================
*/
function wow_output_social_shares_number(){
	global $post;
	$shares_number = get_post_meta( get_the_ID(), 'share-counter', true );
	if ( $shares_number > 0 ) { ?>
		<div class="number-of-shares">
			<?php echo esc_html( $shares_number );  ?>
			<span><?php if ( $shares_number == 1 ) { echo esc_html( 'Share','fribba' ); }  else { echo esc_html( 'Shares','fribba' ); }    ?></span>
		</div>
<?php	}
	
}

/*
=================================================================================================================
wow_header_headline_tagline() - Display header headline/tagline
=================================================================================================================
*/
function wow_header_headline_tagline(){
	$output = '';
	$opts = wow_option('title_tagline');
	$headline = get_option('blogname');
	$tagline = get_option('blogdescription');
	if( $opts == 'both' ){
		$output = '
			<span class="headline">' .esc_html( $headline ) . '</span>
			<span class="tagline">' .esc_html( $tagline ) .'</span>
		';
	}
	elseif( $opts == 'title' ){
		$output = '<span class="headline">' .esc_html( $headline ) . '</span>';
	}	
	elseif( $opts == 'tagline' ){
		$output = '<span class="tagline">' .esc_html( $tagline ) .'</span>';
	}
	
	if( !empty( $output ) ){
		echo '<p class="site-description">' . $output . '</p>';
	}
	
}
/*
=================================================================================================================
wow_display_header() - Display theme header
=================================================================================================================
*/
function wow_display_header(){ 
$h_tag_before = is_front_page() ? '<h1>' : '<h2>';
$h_tag_after = is_front_page() ? '</h1>' : '</h2>';
$logo_center = wow_option('header-style-center');
$logo_center_class = $logo_center ? ' center_style' : '';
?>

		<div class="logo<?php echo esc_attr( $logo_center_class ); ?>">
			<?php echo $h_tag_before; ?>
				<a href="<?php echo esc_url( home_url() ); ?>">
					<?php if ( wow_option( 'logo-type' ) == 'text' && !empty ( wow_option( 'logo-text' ) ) ) { ?>
						<?php echo esc_html ( wow_option( 'logo-text' ) ); ?>
					<?php } elseif ( wow_option( 'logo-type' ) == 'image' && !empty ( wow_option( 'logo-image', 'url' ) ) ) { ?>
						<img src="<?php echo esc_url ( wow_option( 'logo-image','url' ) ) ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>" <?php wow_is_logo_retina(); ?> >
					<?php } else { ?>
						<img src="<?php echo esc_url ( WOW_URI.'/images/logo.png' ) ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>" >
					<?php } 
					?>
					<?php wow_header_headline_tagline(); ?>
				</a>
			<?php echo $h_tag_after; ?>
			
		</div>
		
		<?php if( $logo_center ){?>
			<div class="header-with-logo-center">
		<?php
		}
		?>
		
		<nav class="nav secondary-font">
			<?php wp_nav_menu( array( 'theme_location' => 'header-menu', 'walker' => new WOW_Walker_Nav_Menu() ) ); ?>
		</nav>	
	
		<div class="author-social-search">
			<div class="author-list">
					<?php wow_output_authors(); ?>
			</div>
			<div class="social-and-search">
				<ul>
					<?php wow_output_social(); ?>
					<li class="search-trigger-holder"><a href="#" class="search-trigger" aria-label="<?php esc_attr_e('Search website','fribba') ?>"><?php wow_svg( 'search-line' ) ; ?></a></li>
				</ul>
			</div>
		</div>
		
		<div class="search-mobile search-trigger-holder">
			<button class="search-trigger mobile" aria-label="<?php esc_attr_e('Search website','fribba') ?>"><?php wow_svg( 'search-line' ) ; ?></button>
		</div>
		
		<button class="mobile-trigger mobile-trigger--slider" aria-label="<?php esc_attr_e('Open mobile menu','fribba') ?>" type="button">
		  <span class="mobile-trigger-box">
			<span class="mobile-trigger-inner"></span>
		  </span>
		</button>
		
	<?php get_search_form();  ?>	

		<?php if( $logo_center ){?>
			</div>
		<?php
		}
		?>	
<?php }

/*
=================================================================================================================
wow_is_logo_retina() - Check if logo is retina ready
=================================================================================================================
*/
function wow_is_logo_retina(){
	if ( wow_option( 'logo-type' ) == 'image' && wow_option( 'logo-retina' ) == '1' ){
		echo 'class="retina"';
	}
}