<?php

/*
=================================================================================================================
wow_woo_support() - Declare woocommerce support, and also product gallery, zoom and slider support
=================================================================================================================
*/
function wow_woo_support() {
    add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'wow_woo_support' );

/*
=================================================================================================================
wow_shop_widgets_init() - add widget areas to woo
=================================================================================================================
*/
function wow_shop_widgets_init() {

	register_sidebar( array(
		'name'          => 'WooCommerce',
		'id'            => 'woocommerce',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2>',
		'after_title'   => '</h2>',
	) );	

}
add_action( 'widgets_init', 'wow_shop_widgets_init' );

/*
=================================================================================================================
wow_woo_dequeue_styles() - Dequeue the original woocommerce css files
=================================================================================================================

function wow_woo_dequeue_styles( $enqueue_styles ) {
	unset( $enqueue_styles['woocommerce-smallscreen'] );	# Remove the smallscreen optimisation
	unset( $enqueue_styles['woocommerce-general'] );	# Remove the gloss
	unset( $enqueue_styles['woocommerce-layout'] );		# Remove the layout
	return $enqueue_styles;
}
add_filter( 'woocommerce_enqueue_styles', 'wow_woo_dequeue_styles' );
*/

/*
=================================================================================================================
wow_woo_enqueue_styles() - Enquque the new woocommerce css files
=================================================================================================================
*/
function wow_woo_enqueue_styles(){
	wp_enqueue_style( 'woocommerce-fribba', WOW_URI.'/css/woocommerce.min.css' );
}
add_action( 'wp_enqueue_scripts' , 'wow_woo_enqueue_styles', 11 );


//product title
function wow_woo_loop_product_title() {
	echo '<h2 class="post-title"><a href="'.esc_url( get_the_permalink() ).'">'.esc_html( get_the_title() ).'</a></h2>';
}
add_action('woocommerce_shop_loop_item_title', 'wow_woo_loop_product_title', 10);

//shop breadcrumb 
function wow_shop_breadcrumb() {
	return array(
            'delimiter'   => '&nbsp;&nbsp;&#187;&nbsp;&nbsp;',
			'wrap_before' => '<ul class="breadcrumb">',
			'wrap_after' => '</ul>',
            'before'      => '<li>',
            'after'       => '</li>',
            'home'        => 'Home',
        );
}
add_filter( 'woocommerce_breadcrumb_defaults', 'wow_shop_breadcrumb' );
add_action( 'woocommerce_single_product_summary', 'woocommerce_breadcrumb', 1,1 );
add_action( 'woocommerce_archive_description', 'woocommerce_breadcrumb', 1,1 );

//removed actions
remove_action( 'woocommerce_before_main_content','woocommerce_breadcrumb', 20, 0);
remove_action( 'woocommerce_sidebar','woocommerce_get_sidebar');
remove_action('woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10);

//sidebar grids
if ( wow_option('shop-layout') == 'grid-2-sidebar' || wow_option('shop-layout') == 'grid-3-sidebar' ){

	function wow_before_shop_loop(){
		echo '<div class="wow-inner-row"><!-- start .articles -->';
		echo '<div class="articles '.esc_attr( wow_option('shop-layout') ).' col-desktop-8 col-tablet-12 col-small-tablet-12 col-mobile-12 padding-left-0  padding-right-30 padding-right-tablet-0 padding-left-tablet-0 padding-right-mobile-0 padding-left-mobile-0"><!-- start .articles -->';
			echo '<div class="breadcrumb-navigation visible">';
			echo '<h2 class="page-title">'.esc_html( woocommerce_page_title( false ) ).'</h2>';
			woocommerce_breadcrumb();
			echo '</div>';	
		
	}
	add_action( 'woocommerce_before_shop_loop', 'wow_before_shop_loop', 1,1 );

	function wow_after_shop_loop(){
		echo '</div>';
		get_template_part( 'templates/woo-sidebar' );
		echo '</div>';
		
	}
	add_action( 'woocommerce_after_shop_loop', 'wow_after_shop_loop', 1,1 );
}

//full grids
if ( wow_option('shop-layout') == 'grid-4' || wow_option('shop-layout') == 'grid-3' ){

	function wow_before_shop_loop(){
		echo '<div class="articles '.esc_attr( wow_option('shop-layout') ).'"><!-- start .articles -->';
			echo '<div class="breadcrumb-navigation visible">';
			echo '<h2 class="page-title">'.esc_html( woocommerce_page_title( false ) ).'</h2>';
			woocommerce_breadcrumb();
			echo '</div>';	
		
	}
	add_action( 'woocommerce_before_shop_loop', 'wow_before_shop_loop', 1,1 );
}

/*
=================================================================================================================
wow_shop_sale_text() - Sale text
=================================================================================================================
*/
function wow_shop_sale_text( $text, $post, $_product ){
    return '<span class="onsale"><div class="sale">'.esc_attr__('Sale','fribba').'</div></span>';
}
add_filter('woocommerce_sale_flash', 'wow_shop_sale_text', 10, 3);

/*
=================================================================================================================
wow_shop_comment_args() - Review form
=================================================================================================================
*/
function wow_shop_comment_args( $comment_form ){
	
	$commenter    = wp_get_current_commenter();	
	$name_email_required = (bool) get_option( 'require_name_email', 1 );
	$required = $name_email_required ? ' required' : '';

	$comment_form['comment_notes_before'] = '<p class="comment-notes"><span id="email-notes">' . esc_html__( 'Your email address will not be published.','fribba' ) . '</span></p>';
	$comment_form['title_reply_before'] = '<h3 id="reply-title" class="comment-reply-title">';
	$comment_form['title_reply_after'] = '</h3>';
	$comment_form['fields']['author'] = '<div class="wow-row"><div class="col-desktop-6"><input id="author" name="author" placeholder="'.esc_attr__( 'Your name','fribba' ).'" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" ' . $required . ' /></div>';
	$comment_form['fields']['email'] = '<div class="col-desktop-6"><input id="email" name="email" placeholder="'.esc_attr__( 'Your email','fribba' ).'" type="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" ' . $required . ' /></div></div>';
	$comment_form['fields']['cookies'] = '';
	
	if ( wc_review_ratings_enabled() ) {
		$comment_form['comment_field'] = '<div class="comment-form-rating"><label for="rating">' . esc_html__( 'Your rating', 'fribba' ) . '</label><select name="rating" id="rating" required>
			<option value="">' . esc_html__( 'Rate&hellip;', 'fribba' ) . '</option>
			<option value="5">' . esc_html__( 'Perfect', 'fribba' ) . '</option>
			<option value="4">' . esc_html__( 'Good', 'fribba' ) . '</option>
			<option value="3">' . esc_html__( 'Average', 'fribba' ) . '</option>
			<option value="2">' . esc_html__( 'Not that bad', 'fribba' ) . '</option>
			<option value="1">' . esc_html__( 'Very poor', 'fribba' ) . '</option>
			</select></div>';
	}

	$comment_form['comment_field'] .= '<p class="comment-form-comment"><textarea id="comment" placeholder="'.esc_attr__( 'Leave a review','fribba' ).'" name="comment" cols="45" rows="8" required></textarea></p>';	
	
	return $comment_form;
}
add_filter('woocommerce_product_review_comment_form_args','wow_shop_comment_args');

/*
=================================================================================================================
wow_loop_columns() - Change number or products per row
=================================================================================================================
*/
add_filter('loop_shop_columns', 'wow_loop_columns', 999);
function wow_loop_columns() {
	if ( wow_option('shop-layout') == 'grid-4' ){
		return 4;
	}
	elseif ( wow_option('shop-layout') == 'grid-3' ){
		return 3;
	}		
	elseif ( wow_option('shop-layout') == 'grid-2-sidebar' ){
		return 2;
	}		
	elseif ( wow_option('shop-layout') == 'grid-3-sidebar' ){
		return 3;
	}
}

/*
=================================================================================================================
wow_append_cart_icon() - Append cart item (and cart count) to end of main menu.
=================================================================================================================
*/
add_filter( 'wp_nav_menu_items', 'wow_append_cart_icon', 10, 2 );
function wow_append_cart_icon( $items, $args ) {
	$cart_item_count = WC()->cart->get_cart_contents_count();
	$cart_count_span = '';
	if ( $cart_item_count ) {
		$cart_count_span = '<span class="count">'.$cart_item_count.'</span>';
	}
	$cart_link = '<li class="woo-cart-menu menu-item menu-item-type-post_type menu-item-object-page"><a href="' . get_permalink( wc_get_page_id( 'cart' ) ) . '">'.wow_brands_svg('cart', false).''.$cart_count_span.'</a></li>';
	// Add the cart link to the end of the menu.
	$items = $items . $cart_link;
	return $items;
}

/*
=================================================================================================================
wow_loop_shop_per_page() - Change number of products that are displayed per page (shop page)
=================================================================================================================
*/
add_filter( 'loop_shop_per_page', 'wow_loop_shop_per_page', 20 );

function wow_loop_shop_per_page( $cols ) {
  $cols = !empty ( wow_option( 'shop-per-page' ) ) ? wow_option( 'shop-per-page' ) : 3;
  return $cols;
}


/*
=================================================================================================================
wow_shop_colors() - Shop colors
=================================================================================================================
*/
function wow_shop_colors( $main_color1, $main_color2, $heading_color, $gradient_color3 , $gradient_color4 ){
	
	$output = '
		.woocommerce #respond input#submit, 
		.woocommerce a.button, 
		.woocommerce button.button, 
		.woocommerce input.button,
		.woocommerce #respond input#submit.alt, 
		.woocommerce a.button.alt, 
		.woocommerce button.button.alt, 
		.woocommerce input.button.alt{
			background-color:'.esc_attr( $main_color1 ).';
		}

		.woocommerce #respond input#submit:hover, 
		.woocommerce a.button:hover, 
		.woocommerce button.button:hover, 
		.woocommerce input.button:hover,
		.woocommerce #respond input#submit.alt:hover, 
		.woocommerce a.button.alt:hover, 
		.woocommerce button.button.alt:hover, 
		.woocommerce input.button.alt:hover,
		.woo-cart-menu{
			background-color:'.esc_attr( $main_color2 ).';
		}
		.price
		/* .products li.product:hover .onsale */{
			color:'.esc_attr( $heading_color ).';
		}
		.woocommerce-message,
		.woocommerce .cart-collaterals .cart_totals, 
		.woocommerce-page .cart-collaterals .cart_totals,
		.product_meta{
		   border-color:'.wow_hex( $heading_color, .2 ).';
		}
		.woocommerce span.onsale,
		.woocommerce ul.products li.product .onsale{
			background-image: linear-gradient( to right, '.esc_attr( $gradient_color3 ).' , '.esc_attr( $gradient_color4 ).' );
		}
	';
	
	return $output;
	
}

/*
=================================================================================================================
wow_shop_colors_output() - Output Shop colors
=================================================================================================================
*/
function wow_shop_colors_output(){
	if ( wow_option( 'color-scheme' ) == 'skins' ){
		if ( wow_option( 'skin-colors' ) == 'set1' ){
			echo '<style type="text/css">' .wow_shop_colors( '#FF416C', '#9b539f', '#0e1638', '#FF416C', '#9b539f' ). '</style>';
		}
		elseif ( wow_option( 'skin-colors' ) == 'set2' ){
			echo '<style type="text/css">' .wow_shop_colors( '#2c3e50', '#3498db', '#0e1638', '#FF416C', '#9b539f' ). '</style>';
		}		
		elseif ( wow_option( 'skin-colors' ) == 'set3' ){
			echo '<style type="text/css">' .wow_shop_colors( '#2c3e50', '#FF5722', '#0e1638', '#FF5722', '#FF5722' ). '</style>';
		}		
	}
	elseif( wow_option( 'color-scheme' ) == 'custom' ){
		$main_color1 		= !empty( wow_option( 'custom-colors','color-1' ) ) ? wow_option( 'custom-colors','color-1' ) : '#FF416C';
		$main_color2 		= !empty( wow_option( 'custom-colors','color-2' ) ) ? wow_option( 'custom-colors','color-2' ) : '#9b539f';
		$heading_color 		= !empty( wow_option( 'custom-colors','color-4' ) ) ? wow_option( 'custom-colors','color-4' ) : '#0e1638';
		$gradient_color3 	= !empty( wow_option( 'custom-colors','color-7' ) ) ? wow_option( 'custom-colors','color-7' ) : '#FF416C';
		$gradient_color4 	= !empty( wow_option( 'custom-colors','color-8' ) ) ? wow_option( 'custom-colors','color-8' ) : '#9b539f';		
		
		//only output if there is a color change
		if ( $main_color1 != '#FF416C' ||  $main_color2 != '#9b539f' || $heading_color != '#0e1638' || $gradient_color3 != '#FF416C' ||  $gradient_color4 != '#9b539f' ){
			echo '<style type="text/css">' .wow_shop_colors( $main_color1, $main_color2, $heading_color, $gradient_color3 , $gradient_color4 ). '</style>';
		}
	}
}
add_action('wp_head','wow_shop_colors_output');

/*

// Append cart item (and cart count) to end of main menu.
add_filter( 'wp_nav_menu_items', 'wow_append_cart_icon', 10, 2 );
function wow_append_cart_icon( $items, $args ) {
	$cart_item_count = WC()->cart->get_cart_contents_count();
	$cart_count_span = '';
	if ( $cart_item_count ) {
		$cart_count_span = '<span class="count">'.$cart_item_count.'</span>';
	}
	$cart_link = '<li class="woo-cart-menu menu-item menu-item-type-post_type menu-item-object-page"><a href="' . get_permalink( wc_get_page_id( 'cart' ) ) . '" class="cart-contents">'.wow_brands_svg('cart', false).''.$cart_count_span.'</a></li>';
	// Add the cart link to the end of the menu.
	$items = $items . $cart_link;
	return $items;
}

function wow_header_add_to_cart_fragment( $fragments ) {
 
    ob_start();
    $count = WC()->cart->cart_contents_count;
    ?><a class="cart-contents" href="<?php echo esc_url( wc_get_cart_url() ); ?>" title="<?php esc_html_e( 'View your shopping cart','fribba' ); ?>"><?php wow_brands_svg('cart',false); ?>
	
	<?php
    if ( $count > 0 ) {
        ?>
       <?php echo esc_html( $count ); ?>
        <?php            
    }
        ?></a><?php
 
    $fragments['a.cart-contents'] = ob_get_clean();
     
    return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'wow_header_add_to_cart_fragment' );

function test(){
	
}
remove_action('before_freebies','test');

//var_dump( is_product_category() );

*/